# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.applicationmodel.appservice
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.graphics.directx
import winsdk.windows.graphics.directx.direct3d11
import winsdk.windows.graphics.imaging
import winsdk.windows.storage
import winsdk.windows.storage.streams

class AudioBufferAccessMode(enum.IntEnum):
    READ = 0
    READ_WRITE = 1
    WRITE = 2

class AudioProcessing(enum.IntEnum):
    DEFAULT = 0
    RAW = 1

class MediaPlaybackAutoRepeatMode(enum.IntEnum):
    NONE = 0
    TRACK = 1
    LIST = 2

class MediaPlaybackStatus(enum.IntEnum):
    CLOSED = 0
    CHANGING = 1
    STOPPED = 2
    PLAYING = 3
    PAUSED = 4

class MediaPlaybackType(enum.IntEnum):
    UNKNOWN = 0
    MUSIC = 1
    VIDEO = 2
    IMAGE = 3

class MediaTimelineControllerState(enum.IntEnum):
    PAUSED = 0
    RUNNING = 1
    STALLED = 2
    ERROR = 3

class SoundLevel(enum.IntEnum):
    MUTED = 0
    LOW = 1
    FULL = 2

class SystemMediaTransportControlsButton(enum.IntEnum):
    PLAY = 0
    PAUSE = 1
    STOP = 2
    RECORD = 3
    FAST_FORWARD = 4
    REWIND = 5
    NEXT = 6
    PREVIOUS = 7
    CHANNEL_UP = 8
    CHANNEL_DOWN = 9

class SystemMediaTransportControlsProperty(enum.IntEnum):
    SOUND_LEVEL = 0

Self = typing.TypeVar('Self')

class MediaTimeRange:
    start: datetime.timedelta
    end: datetime.timedelta
    def __new__(cls: typing.Type[MediaTimeRange], start: datetime.timedelta, end: datetime.timedelta) -> MediaTimeRange: ...

class AudioBuffer(winsdk.system.Object):
    length: winsdk.system.UInt32
    capacity: winsdk.system.UInt32
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AudioBuffer: ...
    def close(self) -> None: ...
    def create_reference(self) -> typing.Optional[winsdk.windows.foundation.IMemoryBufferReference]: ...

class AudioFrame(winsdk.system.Object):
    system_relative_time: typing.Optional[typing.Optional[datetime.timedelta]]
    relative_time: typing.Optional[typing.Optional[datetime.timedelta]]
    is_discontinuous: winsdk.system.Boolean
    duration: typing.Optional[typing.Optional[datetime.timedelta]]
    extended_properties: typing.Optional[winsdk.windows.foundation.collections.IPropertySet]
    is_read_only: winsdk.system.Boolean
    type: str
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AudioFrame: ...
    def __new__(cls: typing.Type[AudioFrame], capacity: winsdk.system.UInt32) -> AudioFrame:...
    def close(self) -> None: ...
    def lock_buffer(self, mode: AudioBufferAccessMode) -> typing.Optional[AudioBuffer]: ...

class AutoRepeatModeChangeRequestedEventArgs(winsdk.system.Object):
    requested_auto_repeat_mode: MediaPlaybackAutoRepeatMode
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AutoRepeatModeChangeRequestedEventArgs: ...

class ImageDisplayProperties(winsdk.system.Object):
    title: str
    subtitle: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ImageDisplayProperties: ...

class MediaControl(winsdk.system.Object):
    track_name: typing.ClassVar[str]
    is_playing: typing.ClassVar[winsdk.system.Boolean]
    artist_name: typing.ClassVar[str]
    album_art: typing.ClassVar[typing.Optional[winsdk.windows.foundation.Uri]]
    sound_level: typing.ClassVar[SoundLevel]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaControl: ...
    @staticmethod
    def add_channel_down_pressed(handler: winsdk.windows.foundation.EventHandler[winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_channel_down_pressed(cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    @staticmethod
    def add_channel_up_pressed(handler: winsdk.windows.foundation.EventHandler[winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_channel_up_pressed(cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    @staticmethod
    def add_fast_forward_pressed(handler: winsdk.windows.foundation.EventHandler[winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_fast_forward_pressed(cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    @staticmethod
    def add_next_track_pressed(handler: winsdk.windows.foundation.EventHandler[winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_next_track_pressed(cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    @staticmethod
    def add_pause_pressed(handler: winsdk.windows.foundation.EventHandler[winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_pause_pressed(cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    @staticmethod
    def add_play_pause_toggle_pressed(handler: winsdk.windows.foundation.EventHandler[winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_play_pause_toggle_pressed(cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    @staticmethod
    def add_play_pressed(handler: winsdk.windows.foundation.EventHandler[winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_play_pressed(cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    @staticmethod
    def add_previous_track_pressed(handler: winsdk.windows.foundation.EventHandler[winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_previous_track_pressed(cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    @staticmethod
    def add_record_pressed(handler: winsdk.windows.foundation.EventHandler[winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_record_pressed(cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    @staticmethod
    def add_rewind_pressed(handler: winsdk.windows.foundation.EventHandler[winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_rewind_pressed(cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    @staticmethod
    def add_sound_level_changed(handler: winsdk.windows.foundation.EventHandler[winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_sound_level_changed(cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    @staticmethod
    def add_stop_pressed(handler: winsdk.windows.foundation.EventHandler[winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_stop_pressed(cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class MediaExtensionManager(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaExtensionManager: ...
    def __new__(cls: typing.Type[MediaExtensionManager]) -> MediaExtensionManager:...
    @typing.overload
    def register_audio_decoder(self, activatable_class_id: str, input_subtype: winsdk.system.Guid, output_subtype: winsdk.system.Guid) -> None: ...
    @typing.overload
    def register_audio_decoder(self, activatable_class_id: str, input_subtype: winsdk.system.Guid, output_subtype: winsdk.system.Guid, configuration: typing.Optional[winsdk.windows.foundation.collections.IPropertySet]) -> None: ...
    @typing.overload
    def register_audio_encoder(self, activatable_class_id: str, input_subtype: winsdk.system.Guid, output_subtype: winsdk.system.Guid) -> None: ...
    @typing.overload
    def register_audio_encoder(self, activatable_class_id: str, input_subtype: winsdk.system.Guid, output_subtype: winsdk.system.Guid, configuration: typing.Optional[winsdk.windows.foundation.collections.IPropertySet]) -> None: ...
    @typing.overload
    def register_byte_stream_handler(self, activatable_class_id: str, file_extension: str, mime_type: str) -> None: ...
    @typing.overload
    def register_byte_stream_handler(self, activatable_class_id: str, file_extension: str, mime_type: str, configuration: typing.Optional[winsdk.windows.foundation.collections.IPropertySet]) -> None: ...
    def register_media_extension_for_app_service(self, extension: typing.Optional[IMediaExtension], connection: typing.Optional[winsdk.windows.applicationmodel.appservice.AppServiceConnection]) -> None: ...
    @typing.overload
    def register_scheme_handler(self, activatable_class_id: str, scheme: str) -> None: ...
    @typing.overload
    def register_scheme_handler(self, activatable_class_id: str, scheme: str, configuration: typing.Optional[winsdk.windows.foundation.collections.IPropertySet]) -> None: ...
    @typing.overload
    def register_video_decoder(self, activatable_class_id: str, input_subtype: winsdk.system.Guid, output_subtype: winsdk.system.Guid) -> None: ...
    @typing.overload
    def register_video_decoder(self, activatable_class_id: str, input_subtype: winsdk.system.Guid, output_subtype: winsdk.system.Guid, configuration: typing.Optional[winsdk.windows.foundation.collections.IPropertySet]) -> None: ...
    @typing.overload
    def register_video_encoder(self, activatable_class_id: str, input_subtype: winsdk.system.Guid, output_subtype: winsdk.system.Guid) -> None: ...
    @typing.overload
    def register_video_encoder(self, activatable_class_id: str, input_subtype: winsdk.system.Guid, output_subtype: winsdk.system.Guid, configuration: typing.Optional[winsdk.windows.foundation.collections.IPropertySet]) -> None: ...

class MediaMarkerTypes(winsdk.system.Object):
    bookmark: typing.ClassVar[str]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaMarkerTypes: ...

class MediaProcessingTriggerDetails(winsdk.system.Object):
    arguments: typing.Optional[winsdk.windows.foundation.collections.ValueSet]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaProcessingTriggerDetails: ...

class MediaTimelineController(winsdk.system.Object):
    position: datetime.timedelta
    clock_rate: winsdk.system.Double
    state: MediaTimelineControllerState
    is_looping_enabled: winsdk.system.Boolean
    duration: typing.Optional[typing.Optional[datetime.timedelta]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaTimelineController: ...
    def __new__(cls: typing.Type[MediaTimelineController]) -> MediaTimelineController:...
    def pause(self) -> None: ...
    def resume(self) -> None: ...
    def start(self) -> None: ...
    def add_position_changed(self, position_changed_event_handler: winsdk.windows.foundation.TypedEventHandler[MediaTimelineController, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_position_changed(self, event_cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_state_changed(self, state_changed_event_handler: winsdk.windows.foundation.TypedEventHandler[MediaTimelineController, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_state_changed(self, event_cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_ended(self, event_handler: winsdk.windows.foundation.TypedEventHandler[MediaTimelineController, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_ended(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_failed(self, event_handler: winsdk.windows.foundation.TypedEventHandler[MediaTimelineController, MediaTimelineControllerFailedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_failed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class MediaTimelineControllerFailedEventArgs(winsdk.system.Object):
    extended_error: winsdk.windows.foundation.HResult
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaTimelineControllerFailedEventArgs: ...

class MusicDisplayProperties(winsdk.system.Object):
    title: str
    artist: str
    album_artist: str
    track_number: winsdk.system.UInt32
    album_title: str
    genres: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    album_track_count: winsdk.system.UInt32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MusicDisplayProperties: ...

class PlaybackPositionChangeRequestedEventArgs(winsdk.system.Object):
    requested_playback_position: datetime.timedelta
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PlaybackPositionChangeRequestedEventArgs: ...

class PlaybackRateChangeRequestedEventArgs(winsdk.system.Object):
    requested_playback_rate: winsdk.system.Double
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PlaybackRateChangeRequestedEventArgs: ...

class ShuffleEnabledChangeRequestedEventArgs(winsdk.system.Object):
    requested_shuffle_enabled: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ShuffleEnabledChangeRequestedEventArgs: ...

class SystemMediaTransportControls(winsdk.system.Object):
    is_play_enabled: winsdk.system.Boolean
    is_pause_enabled: winsdk.system.Boolean
    is_next_enabled: winsdk.system.Boolean
    is_previous_enabled: winsdk.system.Boolean
    is_enabled: winsdk.system.Boolean
    is_channel_down_enabled: winsdk.system.Boolean
    is_fast_forward_enabled: winsdk.system.Boolean
    is_channel_up_enabled: winsdk.system.Boolean
    playback_status: MediaPlaybackStatus
    is_stop_enabled: winsdk.system.Boolean
    is_rewind_enabled: winsdk.system.Boolean
    is_record_enabled: winsdk.system.Boolean
    display_updater: typing.Optional[SystemMediaTransportControlsDisplayUpdater]
    sound_level: SoundLevel
    shuffle_enabled: winsdk.system.Boolean
    playback_rate: winsdk.system.Double
    auto_repeat_mode: MediaPlaybackAutoRepeatMode
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SystemMediaTransportControls: ...
    @staticmethod
    def get_for_current_view() -> typing.Optional[SystemMediaTransportControls]: ...
    def update_timeline_properties(self, timeline_properties: typing.Optional[SystemMediaTransportControlsTimelineProperties]) -> None: ...
    def add_button_pressed(self, handler: winsdk.windows.foundation.TypedEventHandler[SystemMediaTransportControls, SystemMediaTransportControlsButtonPressedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_button_pressed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_property_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[SystemMediaTransportControls, SystemMediaTransportControlsPropertyChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_property_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_auto_repeat_mode_change_requested(self, handler: winsdk.windows.foundation.TypedEventHandler[SystemMediaTransportControls, AutoRepeatModeChangeRequestedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_auto_repeat_mode_change_requested(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_playback_position_change_requested(self, handler: winsdk.windows.foundation.TypedEventHandler[SystemMediaTransportControls, PlaybackPositionChangeRequestedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_playback_position_change_requested(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_playback_rate_change_requested(self, handler: winsdk.windows.foundation.TypedEventHandler[SystemMediaTransportControls, PlaybackRateChangeRequestedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_playback_rate_change_requested(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_shuffle_enabled_change_requested(self, handler: winsdk.windows.foundation.TypedEventHandler[SystemMediaTransportControls, ShuffleEnabledChangeRequestedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_shuffle_enabled_change_requested(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class SystemMediaTransportControlsButtonPressedEventArgs(winsdk.system.Object):
    button: SystemMediaTransportControlsButton
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SystemMediaTransportControlsButtonPressedEventArgs: ...

class SystemMediaTransportControlsDisplayUpdater(winsdk.system.Object):
    type: MediaPlaybackType
    thumbnail: typing.Optional[winsdk.windows.storage.streams.RandomAccessStreamReference]
    app_media_id: str
    image_properties: typing.Optional[ImageDisplayProperties]
    music_properties: typing.Optional[MusicDisplayProperties]
    video_properties: typing.Optional[VideoDisplayProperties]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SystemMediaTransportControlsDisplayUpdater: ...
    def clear_all(self) -> None: ...
    def copy_from_file_async(self, type: MediaPlaybackType, source: typing.Optional[winsdk.windows.storage.StorageFile]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def update(self) -> None: ...

class SystemMediaTransportControlsPropertyChangedEventArgs(winsdk.system.Object):
    property: SystemMediaTransportControlsProperty
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SystemMediaTransportControlsPropertyChangedEventArgs: ...

class SystemMediaTransportControlsTimelineProperties(winsdk.system.Object):
    start_time: datetime.timedelta
    position: datetime.timedelta
    min_seek_time: datetime.timedelta
    max_seek_time: datetime.timedelta
    end_time: datetime.timedelta
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SystemMediaTransportControlsTimelineProperties: ...
    def __new__(cls: typing.Type[SystemMediaTransportControlsTimelineProperties]) -> SystemMediaTransportControlsTimelineProperties:...

class VideoDisplayProperties(winsdk.system.Object):
    title: str
    subtitle: str
    genres: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VideoDisplayProperties: ...

class VideoEffects(winsdk.system.Object):
    video_stabilization: typing.ClassVar[str]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VideoEffects: ...

class VideoFrame(winsdk.system.Object):
    system_relative_time: typing.Optional[typing.Optional[datetime.timedelta]]
    relative_time: typing.Optional[typing.Optional[datetime.timedelta]]
    is_discontinuous: winsdk.system.Boolean
    duration: typing.Optional[typing.Optional[datetime.timedelta]]
    extended_properties: typing.Optional[winsdk.windows.foundation.collections.IPropertySet]
    is_read_only: winsdk.system.Boolean
    type: str
    direct3_d_surface: typing.Optional[winsdk.windows.graphics.directx.direct3d11.IDirect3DSurface]
    software_bitmap: typing.Optional[winsdk.windows.graphics.imaging.SoftwareBitmap]
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VideoFrame: ...
    @typing.overload
    def __new__(cls: typing.Type[VideoFrame], format: winsdk.windows.graphics.imaging.BitmapPixelFormat, width: winsdk.system.Int32, height: winsdk.system.Int32) -> VideoFrame:...
    @typing.overload
    def __new__(cls: typing.Type[VideoFrame], format: winsdk.windows.graphics.imaging.BitmapPixelFormat, width: winsdk.system.Int32, height: winsdk.system.Int32, alpha: winsdk.windows.graphics.imaging.BitmapAlphaMode) -> VideoFrame:...
    def close(self) -> None: ...
    @typing.overload
    def copy_to_async(self, frame: typing.Optional[VideoFrame]) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def copy_to_async(self, frame: typing.Optional[VideoFrame], source_bounds: typing.Optional[winsdk.windows.graphics.imaging.BitmapBounds], destination_bounds: typing.Optional[winsdk.windows.graphics.imaging.BitmapBounds]) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    @staticmethod
    def create_as_direct3_d11_surface_backed(format: winsdk.windows.graphics.directx.DirectXPixelFormat, width: winsdk.system.Int32, height: winsdk.system.Int32) -> typing.Optional[VideoFrame]: ...
    @typing.overload
    @staticmethod
    def create_as_direct3_d11_surface_backed(format: winsdk.windows.graphics.directx.DirectXPixelFormat, width: winsdk.system.Int32, height: winsdk.system.Int32, device: typing.Optional[winsdk.windows.graphics.directx.direct3d11.IDirect3DDevice]) -> typing.Optional[VideoFrame]: ...
    @staticmethod
    def create_with_direct3_d11_surface(surface: typing.Optional[winsdk.windows.graphics.directx.direct3d11.IDirect3DSurface]) -> typing.Optional[VideoFrame]: ...
    @staticmethod
    def create_with_software_bitmap(bitmap: typing.Optional[winsdk.windows.graphics.imaging.SoftwareBitmap]) -> typing.Optional[VideoFrame]: ...

class IMediaExtension(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IMediaExtension: ...
    def set_properties(self, configuration: typing.Optional[winsdk.windows.foundation.collections.IPropertySet]) -> None: ...

class IMediaFrame(winsdk.system.Object):
    duration: typing.Optional[typing.Optional[datetime.timedelta]]
    extended_properties: typing.Optional[winsdk.windows.foundation.collections.IPropertySet]
    is_discontinuous: winsdk.system.Boolean
    is_read_only: winsdk.system.Boolean
    relative_time: typing.Optional[typing.Optional[datetime.timedelta]]
    system_relative_time: typing.Optional[typing.Optional[datetime.timedelta]]
    type: str
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IMediaFrame: ...
    def close(self) -> None: ...

class IMediaMarker(winsdk.system.Object):
    media_marker_type: str
    text: str
    time: datetime.timedelta
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IMediaMarker: ...

class IMediaMarkers(winsdk.system.Object):
    markers: typing.Optional[winsdk.windows.foundation.collections.IVectorView[IMediaMarker]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IMediaMarkers: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Perception.Spatial")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.foundation.numerics
except ImportError:
    pass

try:
    import winsdk.windows.perception
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

try:
    import winsdk.windows.system.remotesystems
except ImportError:
    pass

class SpatialAnchorExportPurpose(enum.IntEnum):
    RELOCALIZATION = 0
    SHARING = 1

class SpatialEntityWatcherStatus(enum.IntEnum):
    CREATED = 0
    STARTED = 1
    ENUMERATION_COMPLETED = 2
    STOPPING = 3
    STOPPED = 4
    ABORTED = 5

class SpatialLocatability(enum.IntEnum):
    UNAVAILABLE = 0
    ORIENTATION_ONLY = 1
    POSITIONAL_TRACKING_ACTIVATING = 2
    POSITIONAL_TRACKING_ACTIVE = 3
    POSITIONAL_TRACKING_INHIBITED = 4

class SpatialLookDirectionRange(enum.IntEnum):
    FORWARD_ONLY = 0
    OMNIDIRECTIONAL = 1

class SpatialMovementRange(enum.IntEnum):
    NO_MOVEMENT = 0
    BOUNDED = 1

class SpatialPerceptionAccessStatus(enum.IntEnum):
    UNSPECIFIED = 0
    ALLOWED = 1
    DENIED_BY_USER = 2
    DENIED_BY_SYSTEM = 3

_ns_module._register_SpatialAnchorExportPurpose(SpatialAnchorExportPurpose)
_ns_module._register_SpatialEntityWatcherStatus(SpatialEntityWatcherStatus)
_ns_module._register_SpatialLocatability(SpatialLocatability)
_ns_module._register_SpatialLookDirectionRange(SpatialLookDirectionRange)
_ns_module._register_SpatialMovementRange(SpatialMovementRange)
_ns_module._register_SpatialPerceptionAccessStatus(SpatialPerceptionAccessStatus)

SpatialBoundingBox = _ns_module.SpatialBoundingBox
SpatialBoundingFrustum = _ns_module.SpatialBoundingFrustum
SpatialBoundingOrientedBox = _ns_module.SpatialBoundingOrientedBox
SpatialBoundingSphere = _ns_module.SpatialBoundingSphere
SpatialRay = _ns_module.SpatialRay
SpatialAnchor = _ns_module.SpatialAnchor
SpatialAnchorExportSufficiency = _ns_module.SpatialAnchorExportSufficiency
SpatialAnchorExporter = _ns_module.SpatialAnchorExporter
SpatialAnchorManager = _ns_module.SpatialAnchorManager
SpatialAnchorRawCoordinateSystemAdjustedEventArgs = _ns_module.SpatialAnchorRawCoordinateSystemAdjustedEventArgs
SpatialAnchorStore = _ns_module.SpatialAnchorStore
SpatialAnchorTransferManager = _ns_module.SpatialAnchorTransferManager
SpatialBoundingVolume = _ns_module.SpatialBoundingVolume
SpatialCoordinateSystem = _ns_module.SpatialCoordinateSystem
SpatialEntity = _ns_module.SpatialEntity
SpatialEntityAddedEventArgs = _ns_module.SpatialEntityAddedEventArgs
SpatialEntityRemovedEventArgs = _ns_module.SpatialEntityRemovedEventArgs
SpatialEntityStore = _ns_module.SpatialEntityStore
SpatialEntityUpdatedEventArgs = _ns_module.SpatialEntityUpdatedEventArgs
SpatialEntityWatcher = _ns_module.SpatialEntityWatcher
SpatialLocation = _ns_module.SpatialLocation
SpatialLocator = _ns_module.SpatialLocator
SpatialLocatorAttachedFrameOfReference = _ns_module.SpatialLocatorAttachedFrameOfReference
SpatialLocatorPositionalTrackingDeactivatingEventArgs = _ns_module.SpatialLocatorPositionalTrackingDeactivatingEventArgs
SpatialStageFrameOfReference = _ns_module.SpatialStageFrameOfReference
SpatialStationaryFrameOfReference = _ns_module.SpatialStationaryFrameOfReference



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.ui.windowmanagement

Self = typing.TypeVar('Self')

class CoreAppWindowPreview(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> CoreAppWindowPreview: ...
    @staticmethod
    def get_id_from_window(window: typing.Optional[winsdk.windows.ui.windowmanagement.AppWindow]) -> winsdk.system.Int32: ...

class SystemNavigationCloseRequestedPreviewEventArgs(winsdk.system.Object):
    handled: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SystemNavigationCloseRequestedPreviewEventArgs: ...
    def get_deferral(self) -> typing.Optional[winsdk.windows.foundation.Deferral]: ...

class SystemNavigationManagerPreview(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SystemNavigationManagerPreview: ...
    @staticmethod
    def get_for_current_view() -> typing.Optional[SystemNavigationManagerPreview]: ...
    def add_close_requested(self, handler: winsdk.windows.foundation.EventHandler[SystemNavigationCloseRequestedPreviewEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_close_requested(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.UI.Notifications.Management")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.ui.notifications
except ImportError:
    pass

class UserNotificationListenerAccessStatus(enum.IntEnum):
    UNSPECIFIED = 0
    ALLOWED = 1
    DENIED = 2

_ns_module._register_UserNotificationListenerAccessStatus(UserNotificationListenerAccessStatus)

UserNotificationListener = _ns_module.UserNotificationListener



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Networking.ServiceDiscovery.Dnssd")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.networking
except ImportError:
    pass

try:
    import winsdk.windows.networking.connectivity
except ImportError:
    pass

try:
    import winsdk.windows.networking.sockets
except ImportError:
    pass

class DnssdRegistrationStatus(enum.IntEnum):
    SUCCESS = 0
    INVALID_SERVICE_NAME = 1
    SERVER_ERROR = 2
    SECURITY_ERROR = 3

class DnssdServiceWatcherStatus(enum.IntEnum):
    CREATED = 0
    STARTED = 1
    ENUMERATION_COMPLETED = 2
    STOPPING = 3
    STOPPED = 4
    ABORTED = 5

_ns_module._register_DnssdRegistrationStatus(DnssdRegistrationStatus)
_ns_module._register_DnssdServiceWatcherStatus(DnssdServiceWatcherStatus)

DnssdRegistrationResult = _ns_module.DnssdRegistrationResult
DnssdServiceInstance = _ns_module.DnssdServiceInstance
DnssdServiceInstanceCollection = _ns_module.DnssdServiceInstanceCollection
DnssdServiceWatcher = _ns_module.DnssdServiceWatcher



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Security.Credentials")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.security.cryptography.core
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

try:
    import winsdk.windows.system
except ImportError:
    pass

class KeyCredentialAttestationStatus(enum.IntEnum):
    SUCCESS = 0
    UNKNOWN_ERROR = 1
    NOT_SUPPORTED = 2
    TEMPORARY_FAILURE = 3

class KeyCredentialCreationOption(enum.IntEnum):
    REPLACE_EXISTING = 0
    FAIL_IF_EXISTS = 1

class KeyCredentialStatus(enum.IntEnum):
    SUCCESS = 0
    UNKNOWN_ERROR = 1
    NOT_FOUND = 2
    USER_CANCELED = 3
    USER_PREFERS_PASSWORD = 4
    CREDENTIAL_ALREADY_EXISTS = 5
    SECURITY_DEVICE_LOCKED = 6

class WebAccountPictureSize(enum.IntEnum):
    SIZE64X64 = 64
    SIZE208X208 = 208
    SIZE424X424 = 424
    SIZE1080X1080 = 1080

class WebAccountState(enum.IntEnum):
    NONE = 0
    CONNECTED = 1
    ERROR = 2

_ns_module._register_KeyCredentialAttestationStatus(KeyCredentialAttestationStatus)
_ns_module._register_KeyCredentialCreationOption(KeyCredentialCreationOption)
_ns_module._register_KeyCredentialStatus(KeyCredentialStatus)
_ns_module._register_WebAccountPictureSize(WebAccountPictureSize)
_ns_module._register_WebAccountState(WebAccountState)

KeyCredential = _ns_module.KeyCredential
KeyCredentialAttestationResult = _ns_module.KeyCredentialAttestationResult
KeyCredentialManager = _ns_module.KeyCredentialManager
KeyCredentialOperationResult = _ns_module.KeyCredentialOperationResult
KeyCredentialRetrievalResult = _ns_module.KeyCredentialRetrievalResult
PasswordCredential = _ns_module.PasswordCredential
PasswordCredentialPropertyStore = _ns_module.PasswordCredentialPropertyStore
PasswordVault = _ns_module.PasswordVault
WebAccount = _ns_module.WebAccount
WebAccountProvider = _ns_module.WebAccountProvider
IWebAccount = _ns_module.IWebAccount



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.devices.geolocation
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.storage
import winsdk.windows.storage.streams

class PhotoOrientation(enum.IntEnum):
    UNSPECIFIED = 0
    NORMAL = 1
    FLIP_HORIZONTAL = 2
    ROTATE180 = 3
    FLIP_VERTICAL = 4
    TRANSPOSE = 5
    ROTATE270 = 6
    TRANSVERSE = 7
    ROTATE90 = 8

class PropertyPrefetchOptions(enum.IntFlag):
    NONE = 0
    MUSIC_PROPERTIES = 0x1
    VIDEO_PROPERTIES = 0x2
    IMAGE_PROPERTIES = 0x4
    DOCUMENT_PROPERTIES = 0x8
    BASIC_PROPERTIES = 0x10

class ThumbnailMode(enum.IntEnum):
    PICTURES_VIEW = 0
    VIDEOS_VIEW = 1
    MUSIC_VIEW = 2
    DOCUMENTS_VIEW = 3
    LIST_VIEW = 4
    SINGLE_ITEM = 5

class ThumbnailOptions(enum.IntFlag):
    NONE = 0
    RETURN_ONLY_IF_CACHED = 0x1
    RESIZE_THUMBNAIL = 0x2
    USE_CURRENT_SCALE = 0x4

class ThumbnailType(enum.IntEnum):
    IMAGE = 0
    ICON = 1

class VideoOrientation(enum.IntEnum):
    NORMAL = 0
    ROTATE90 = 90
    ROTATE180 = 180
    ROTATE270 = 270

Self = typing.TypeVar('Self')

class BasicProperties(winsdk.system.Object):
    date_modified: datetime.datetime
    item_date: datetime.datetime
    size: winsdk.system.UInt64
    @staticmethod
    def _from(obj: winsdk.system.Object) -> BasicProperties: ...
    def retrieve_properties_async(self, properties_to_retrieve: typing.Iterable[str]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IMap[str, winsdk.system.Object]]: ...
    @typing.overload
    def save_properties_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def save_properties_async(self, properties_to_save: typing.Iterable[winsdk.windows.foundation.collections.IKeyValuePair[str, winsdk.system.Object]]) -> winsdk.windows.foundation.IAsyncAction: ...

class DocumentProperties(winsdk.system.Object):
    title: str
    comment: str
    author: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    keywords: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DocumentProperties: ...
    def retrieve_properties_async(self, properties_to_retrieve: typing.Iterable[str]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IMap[str, winsdk.system.Object]]: ...
    @typing.overload
    def save_properties_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def save_properties_async(self, properties_to_save: typing.Iterable[winsdk.windows.foundation.collections.IKeyValuePair[str, winsdk.system.Object]]) -> winsdk.windows.foundation.IAsyncAction: ...

class GeotagHelper(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> GeotagHelper: ...
    @staticmethod
    def get_geotag_async(file: typing.Optional[winsdk.windows.storage.IStorageFile]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.devices.geolocation.Geopoint]: ...
    @staticmethod
    def set_geotag_async(file: typing.Optional[winsdk.windows.storage.IStorageFile], geopoint: typing.Optional[winsdk.windows.devices.geolocation.Geopoint]) -> winsdk.windows.foundation.IAsyncAction: ...
    @staticmethod
    def set_geotag_from_geolocator_async(file: typing.Optional[winsdk.windows.storage.IStorageFile], geolocator: typing.Optional[winsdk.windows.devices.geolocation.Geolocator]) -> winsdk.windows.foundation.IAsyncAction: ...

class ImageProperties(winsdk.system.Object):
    title: str
    rating: winsdk.system.UInt32
    date_taken: datetime.datetime
    camera_model: str
    camera_manufacturer: str
    height: winsdk.system.UInt32
    keywords: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    latitude: typing.Optional[typing.Optional[winsdk.system.Double]]
    longitude: typing.Optional[typing.Optional[winsdk.system.Double]]
    orientation: PhotoOrientation
    people_names: typing.Optional[winsdk.windows.foundation.collections.IVectorView[str]]
    width: winsdk.system.UInt32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ImageProperties: ...
    def retrieve_properties_async(self, properties_to_retrieve: typing.Iterable[str]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IMap[str, winsdk.system.Object]]: ...
    @typing.overload
    def save_properties_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def save_properties_async(self, properties_to_save: typing.Iterable[winsdk.windows.foundation.collections.IKeyValuePair[str, winsdk.system.Object]]) -> winsdk.windows.foundation.IAsyncAction: ...

class MusicProperties(winsdk.system.Object):
    year: winsdk.system.UInt32
    track_number: winsdk.system.UInt32
    title: str
    subtitle: str
    rating: winsdk.system.UInt32
    publisher: str
    artist: str
    album_artist: str
    album: str
    bitrate: winsdk.system.UInt32
    composers: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    conductors: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    duration: datetime.timedelta
    genre: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    producers: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    writers: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MusicProperties: ...
    def retrieve_properties_async(self, properties_to_retrieve: typing.Iterable[str]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IMap[str, winsdk.system.Object]]: ...
    @typing.overload
    def save_properties_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def save_properties_async(self, properties_to_save: typing.Iterable[winsdk.windows.foundation.collections.IKeyValuePair[str, winsdk.system.Object]]) -> winsdk.windows.foundation.IAsyncAction: ...

class StorageItemContentProperties(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StorageItemContentProperties: ...
    def get_document_properties_async(self) -> winsdk.windows.foundation.IAsyncOperation[DocumentProperties]: ...
    def get_image_properties_async(self) -> winsdk.windows.foundation.IAsyncOperation[ImageProperties]: ...
    def get_music_properties_async(self) -> winsdk.windows.foundation.IAsyncOperation[MusicProperties]: ...
    def get_video_properties_async(self) -> winsdk.windows.foundation.IAsyncOperation[VideoProperties]: ...
    def retrieve_properties_async(self, properties_to_retrieve: typing.Iterable[str]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IMap[str, winsdk.system.Object]]: ...
    @typing.overload
    def save_properties_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def save_properties_async(self, properties_to_save: typing.Iterable[winsdk.windows.foundation.collections.IKeyValuePair[str, winsdk.system.Object]]) -> winsdk.windows.foundation.IAsyncAction: ...

class StorageItemThumbnail(winsdk.system.Object):
    original_height: winsdk.system.UInt32
    original_width: winsdk.system.UInt32
    returned_smaller_cached_size: winsdk.system.Boolean
    type: ThumbnailType
    content_type: str
    size: winsdk.system.UInt64
    can_read: winsdk.system.Boolean
    can_write: winsdk.system.Boolean
    position: winsdk.system.UInt64
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StorageItemThumbnail: ...
    def clone_stream(self) -> typing.Optional[winsdk.windows.storage.streams.IRandomAccessStream]: ...
    def close(self) -> None: ...
    def flush_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def get_input_stream_at(self, position: winsdk.system.UInt64) -> typing.Optional[winsdk.windows.storage.streams.IInputStream]: ...
    def get_output_stream_at(self, position: winsdk.system.UInt64) -> typing.Optional[winsdk.windows.storage.streams.IOutputStream]: ...
    def read_async(self, buffer: typing.Optional[winsdk.windows.storage.streams.IBuffer], count: winsdk.system.UInt32, options: winsdk.windows.storage.streams.InputStreamOptions) -> winsdk.windows.foundation.IAsyncOperationWithProgress[winsdk.windows.storage.streams.IBuffer, winsdk.system.UInt32]: ...
    def seek(self, position: winsdk.system.UInt64) -> None: ...
    def write_async(self, buffer: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> winsdk.windows.foundation.IAsyncOperationWithProgress[winsdk.system.UInt32, winsdk.system.UInt32]: ...

class VideoProperties(winsdk.system.Object):
    year: winsdk.system.UInt32
    title: str
    subtitle: str
    rating: winsdk.system.UInt32
    publisher: str
    bitrate: winsdk.system.UInt32
    directors: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    duration: datetime.timedelta
    height: winsdk.system.UInt32
    keywords: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    latitude: typing.Optional[typing.Optional[winsdk.system.Double]]
    longitude: typing.Optional[typing.Optional[winsdk.system.Double]]
    orientation: VideoOrientation
    producers: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    width: winsdk.system.UInt32
    writers: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VideoProperties: ...
    def retrieve_properties_async(self, properties_to_retrieve: typing.Iterable[str]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IMap[str, winsdk.system.Object]]: ...
    @typing.overload
    def save_properties_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def save_properties_async(self, properties_to_save: typing.Iterable[winsdk.windows.foundation.collections.IKeyValuePair[str, winsdk.system.Object]]) -> winsdk.windows.foundation.IAsyncAction: ...

class IStorageItemExtraProperties(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IStorageItemExtraProperties: ...
    def retrieve_properties_async(self, properties_to_retrieve: typing.Iterable[str]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IMap[str, winsdk.system.Object]]: ...
    @typing.overload
    def save_properties_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def save_properties_async(self, properties_to_save: typing.Iterable[winsdk.windows.foundation.collections.IKeyValuePair[str, winsdk.system.Object]]) -> winsdk.windows.foundation.IAsyncAction: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Devices.Radios")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

class RadioAccessStatus(enum.IntEnum):
    UNSPECIFIED = 0
    ALLOWED = 1
    DENIED_BY_USER = 2
    DENIED_BY_SYSTEM = 3

class RadioKind(enum.IntEnum):
    OTHER = 0
    WI_FI = 1
    MOBILE_BROADBAND = 2
    BLUETOOTH = 3
    F_M = 4

class RadioState(enum.IntEnum):
    UNKNOWN = 0
    ON = 1
    OFF = 2
    DISABLED = 3

_ns_module._register_RadioAccessStatus(RadioAccessStatus)
_ns_module._register_RadioKind(RadioKind)
_ns_module._register_RadioState(RadioState)

Radio = _ns_module.Radio



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.globalization
import winsdk.windows.storage
import winsdk.windows.storage.streams
import winsdk.windows.system

class AccountPictureKind(enum.IntEnum):
    SMALL_IMAGE = 0
    LARGE_IMAGE = 1
    VIDEO = 2

class SetAccountPictureResult(enum.IntEnum):
    SUCCESS = 0
    CHANGE_DISABLED = 1
    LARGE_OR_DYNAMIC_ERROR = 2
    VIDEO_FRAME_SIZE_ERROR = 3
    FILE_SIZE_ERROR = 4
    FAILURE = 5

class SetImageFeedResult(enum.IntEnum):
    SUCCESS = 0
    CHANGE_DISABLED = 1
    USER_CANCELED = 2

Self = typing.TypeVar('Self')

class AdvertisingManager(winsdk.system.Object):
    advertising_id: typing.ClassVar[str]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AdvertisingManager: ...
    @staticmethod
    def get_for_user(user: typing.Optional[winsdk.windows.system.User]) -> typing.Optional[AdvertisingManagerForUser]: ...

class AdvertisingManagerForUser(winsdk.system.Object):
    advertising_id: str
    user: typing.Optional[winsdk.windows.system.User]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AdvertisingManagerForUser: ...

class AssignedAccessSettings(winsdk.system.Object):
    is_enabled: winsdk.system.Boolean
    is_single_app_kiosk_mode: winsdk.system.Boolean
    user: typing.Optional[winsdk.windows.system.User]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AssignedAccessSettings: ...
    @staticmethod
    def get_default() -> typing.Optional[AssignedAccessSettings]: ...
    @staticmethod
    def get_for_user(user: typing.Optional[winsdk.windows.system.User]) -> typing.Optional[AssignedAccessSettings]: ...

class DiagnosticsSettings(winsdk.system.Object):
    can_use_diagnostics_to_tailor_experiences: winsdk.system.Boolean
    user: typing.Optional[winsdk.windows.system.User]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DiagnosticsSettings: ...
    @staticmethod
    def get_default() -> typing.Optional[DiagnosticsSettings]: ...
    @staticmethod
    def get_for_user(user: typing.Optional[winsdk.windows.system.User]) -> typing.Optional[DiagnosticsSettings]: ...

class FirstSignInSettings(winsdk.system.Object, typing.Mapping[str, winsdk.system.Object]):
    size: winsdk.system.UInt32
    def __len__(self) -> int: ...
    def __iter__(self) -> typing.Iterator[str]: ...
    def __contains__(self, key: object) -> bool:...
    def __getitem__(self, key: str) -> winsdk.system.Object: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> FirstSignInSettings: ...
    def first(self) -> typing.Optional[winsdk.windows.foundation.collections.IIterator[winsdk.windows.foundation.collections.IKeyValuePair[str, winsdk.system.Object]]]: ...
    @staticmethod
    def get_default() -> typing.Optional[FirstSignInSettings]: ...
    def has_key(self, key: str) -> winsdk.system.Boolean: ...
    def lookup(self, key: str) -> typing.Optional[winsdk.system.Object]: ...
    def split(self) -> typing.Tuple[typing.Optional[winsdk.windows.foundation.collections.IMapView[str, winsdk.system.Object]], typing.Optional[winsdk.windows.foundation.collections.IMapView[str, winsdk.system.Object]]]: ...

class GlobalizationPreferences(winsdk.system.Object):
    calendars: typing.ClassVar[typing.Optional[winsdk.windows.foundation.collections.IVectorView[str]]]
    clocks: typing.ClassVar[typing.Optional[winsdk.windows.foundation.collections.IVectorView[str]]]
    currencies: typing.ClassVar[typing.Optional[winsdk.windows.foundation.collections.IVectorView[str]]]
    home_geographic_region: typing.ClassVar[str]
    languages: typing.ClassVar[typing.Optional[winsdk.windows.foundation.collections.IVectorView[str]]]
    week_starts_on: typing.ClassVar[winsdk.windows.globalization.DayOfWeek]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> GlobalizationPreferences: ...
    @staticmethod
    def get_for_user(user: typing.Optional[winsdk.windows.system.User]) -> typing.Optional[GlobalizationPreferencesForUser]: ...
    @staticmethod
    def try_set_home_geographic_region(region: str) -> winsdk.system.Boolean: ...
    @staticmethod
    def try_set_languages(language_tags: typing.Iterable[str]) -> winsdk.system.Boolean: ...

class GlobalizationPreferencesForUser(winsdk.system.Object):
    calendars: typing.Optional[winsdk.windows.foundation.collections.IVectorView[str]]
    clocks: typing.Optional[winsdk.windows.foundation.collections.IVectorView[str]]
    currencies: typing.Optional[winsdk.windows.foundation.collections.IVectorView[str]]
    home_geographic_region: str
    languages: typing.Optional[winsdk.windows.foundation.collections.IVectorView[str]]
    user: typing.Optional[winsdk.windows.system.User]
    week_starts_on: winsdk.windows.globalization.DayOfWeek
    @staticmethod
    def _from(obj: winsdk.system.Object) -> GlobalizationPreferencesForUser: ...

class LockScreen(winsdk.system.Object):
    original_image_file: typing.ClassVar[typing.Optional[winsdk.windows.foundation.Uri]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> LockScreen: ...
    @staticmethod
    def get_image_stream() -> typing.Optional[winsdk.windows.storage.streams.IRandomAccessStream]: ...
    @staticmethod
    def request_set_image_feed_async(syndication_feed_uri: typing.Optional[winsdk.windows.foundation.Uri]) -> winsdk.windows.foundation.IAsyncOperation[SetImageFeedResult]: ...
    @staticmethod
    def set_image_file_async(value: typing.Optional[winsdk.windows.storage.IStorageFile]) -> winsdk.windows.foundation.IAsyncAction: ...
    @staticmethod
    def set_image_stream_async(value: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStream]) -> winsdk.windows.foundation.IAsyncAction: ...
    @staticmethod
    def try_remove_image_feed() -> winsdk.system.Boolean: ...

class UserInformation(winsdk.system.Object):
    account_picture_change_enabled: typing.ClassVar[winsdk.system.Boolean]
    name_access_allowed: typing.ClassVar[winsdk.system.Boolean]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UserInformation: ...
    @staticmethod
    def get_account_picture(kind: AccountPictureKind) -> typing.Optional[winsdk.windows.storage.IStorageFile]: ...
    @staticmethod
    def get_display_name_async() -> winsdk.windows.foundation.IAsyncOperation[str]: ...
    @staticmethod
    def get_domain_name_async() -> winsdk.windows.foundation.IAsyncOperation[str]: ...
    @staticmethod
    def get_first_name_async() -> winsdk.windows.foundation.IAsyncOperation[str]: ...
    @staticmethod
    def get_last_name_async() -> winsdk.windows.foundation.IAsyncOperation[str]: ...
    @staticmethod
    def get_principal_name_async() -> winsdk.windows.foundation.IAsyncOperation[str]: ...
    @staticmethod
    def get_session_initiation_protocol_uri_async() -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.Uri]: ...
    @staticmethod
    def set_account_picture_async(image: typing.Optional[winsdk.windows.storage.IStorageFile]) -> winsdk.windows.foundation.IAsyncOperation[SetAccountPictureResult]: ...
    @staticmethod
    def set_account_picture_from_stream_async(image: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStream]) -> winsdk.windows.foundation.IAsyncOperation[SetAccountPictureResult]: ...
    @staticmethod
    def set_account_pictures_async(small_image: typing.Optional[winsdk.windows.storage.IStorageFile], large_image: typing.Optional[winsdk.windows.storage.IStorageFile], video: typing.Optional[winsdk.windows.storage.IStorageFile]) -> winsdk.windows.foundation.IAsyncOperation[SetAccountPictureResult]: ...
    @staticmethod
    def set_account_pictures_from_streams_async(small_image: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStream], large_image: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStream], video: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStream]) -> winsdk.windows.foundation.IAsyncOperation[SetAccountPictureResult]: ...
    @staticmethod
    def add_account_picture_changed(change_handler: winsdk.windows.foundation.EventHandler[winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    @staticmethod
    def remove_account_picture_changed(token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class UserProfilePersonalizationSettings(winsdk.system.Object):
    current: typing.ClassVar[typing.Optional[UserProfilePersonalizationSettings]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UserProfilePersonalizationSettings: ...
    @staticmethod
    def is_supported() -> winsdk.system.Boolean: ...
    def try_set_lock_screen_image_async(self, image_file: typing.Optional[winsdk.windows.storage.StorageFile]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def try_set_wallpaper_image_async(self, image_file: typing.Optional[winsdk.windows.storage.StorageFile]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.media
import winsdk.windows.storage.streams

class GlobalSystemMediaTransportControlsSessionPlaybackStatus(enum.IntEnum):
    CLOSED = 0
    OPENED = 1
    CHANGING = 2
    STOPPED = 3
    PLAYING = 4
    PAUSED = 5

Self = typing.TypeVar('Self')

class CurrentSessionChangedEventArgs(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> CurrentSessionChangedEventArgs: ...

class GlobalSystemMediaTransportControlsSession(winsdk.system.Object):
    source_app_user_model_id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> GlobalSystemMediaTransportControlsSession: ...
    def get_playback_info(self) -> typing.Optional[GlobalSystemMediaTransportControlsSessionPlaybackInfo]: ...
    def get_timeline_properties(self) -> typing.Optional[GlobalSystemMediaTransportControlsSessionTimelineProperties]: ...
    def try_change_auto_repeat_mode_async(self, requested_auto_repeat_mode: winsdk.windows.media.MediaPlaybackAutoRepeatMode) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def try_change_channel_down_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def try_change_channel_up_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def try_change_playback_position_async(self, requested_playback_position: winsdk.system.Int64) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def try_change_playback_rate_async(self, requested_playback_rate: winsdk.system.Double) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def try_change_shuffle_active_async(self, requested_shuffle_state: winsdk.system.Boolean) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def try_fast_forward_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def try_get_media_properties_async(self) -> winsdk.windows.foundation.IAsyncOperation[GlobalSystemMediaTransportControlsSessionMediaProperties]: ...
    def try_pause_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def try_play_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def try_record_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def try_rewind_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def try_skip_next_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def try_skip_previous_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def try_stop_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def try_toggle_play_pause_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def add_media_properties_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[GlobalSystemMediaTransportControlsSession, MediaPropertiesChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_media_properties_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_playback_info_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[GlobalSystemMediaTransportControlsSession, PlaybackInfoChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_playback_info_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_timeline_properties_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[GlobalSystemMediaTransportControlsSession, TimelinePropertiesChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_timeline_properties_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class GlobalSystemMediaTransportControlsSessionManager(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> GlobalSystemMediaTransportControlsSessionManager: ...
    def get_current_session(self) -> typing.Optional[GlobalSystemMediaTransportControlsSession]: ...
    def get_sessions(self) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[GlobalSystemMediaTransportControlsSession]]: ...
    @staticmethod
    def request_async() -> winsdk.windows.foundation.IAsyncOperation[GlobalSystemMediaTransportControlsSessionManager]: ...
    def add_current_session_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[GlobalSystemMediaTransportControlsSessionManager, CurrentSessionChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_current_session_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_sessions_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[GlobalSystemMediaTransportControlsSessionManager, SessionsChangedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_sessions_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class GlobalSystemMediaTransportControlsSessionMediaProperties(winsdk.system.Object):
    album_artist: str
    album_title: str
    album_track_count: winsdk.system.Int32
    artist: str
    genres: typing.Optional[winsdk.windows.foundation.collections.IVectorView[str]]
    playback_type: typing.Optional[typing.Optional[winsdk.windows.media.MediaPlaybackType]]
    subtitle: str
    thumbnail: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStreamReference]
    title: str
    track_number: winsdk.system.Int32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> GlobalSystemMediaTransportControlsSessionMediaProperties: ...

class GlobalSystemMediaTransportControlsSessionPlaybackControls(winsdk.system.Object):
    is_channel_down_enabled: winsdk.system.Boolean
    is_channel_up_enabled: winsdk.system.Boolean
    is_fast_forward_enabled: winsdk.system.Boolean
    is_next_enabled: winsdk.system.Boolean
    is_pause_enabled: winsdk.system.Boolean
    is_play_enabled: winsdk.system.Boolean
    is_play_pause_toggle_enabled: winsdk.system.Boolean
    is_playback_position_enabled: winsdk.system.Boolean
    is_playback_rate_enabled: winsdk.system.Boolean
    is_previous_enabled: winsdk.system.Boolean
    is_record_enabled: winsdk.system.Boolean
    is_repeat_enabled: winsdk.system.Boolean
    is_rewind_enabled: winsdk.system.Boolean
    is_shuffle_enabled: winsdk.system.Boolean
    is_stop_enabled: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> GlobalSystemMediaTransportControlsSessionPlaybackControls: ...

class GlobalSystemMediaTransportControlsSessionPlaybackInfo(winsdk.system.Object):
    auto_repeat_mode: typing.Optional[typing.Optional[winsdk.windows.media.MediaPlaybackAutoRepeatMode]]
    controls: typing.Optional[GlobalSystemMediaTransportControlsSessionPlaybackControls]
    is_shuffle_active: typing.Optional[typing.Optional[winsdk.system.Boolean]]
    playback_rate: typing.Optional[typing.Optional[winsdk.system.Double]]
    playback_status: GlobalSystemMediaTransportControlsSessionPlaybackStatus
    playback_type: typing.Optional[typing.Optional[winsdk.windows.media.MediaPlaybackType]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> GlobalSystemMediaTransportControlsSessionPlaybackInfo: ...

class GlobalSystemMediaTransportControlsSessionTimelineProperties(winsdk.system.Object):
    end_time: datetime.timedelta
    last_updated_time: datetime.datetime
    max_seek_time: datetime.timedelta
    min_seek_time: datetime.timedelta
    position: datetime.timedelta
    start_time: datetime.timedelta
    @staticmethod
    def _from(obj: winsdk.system.Object) -> GlobalSystemMediaTransportControlsSessionTimelineProperties: ...

class MediaPropertiesChangedEventArgs(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> MediaPropertiesChangedEventArgs: ...

class PlaybackInfoChangedEventArgs(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PlaybackInfoChangedEventArgs: ...

class SessionsChangedEventArgs(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SessionsChangedEventArgs: ...

class TimelinePropertiesChangedEventArgs(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> TimelinePropertiesChangedEventArgs: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.UI.Text")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

try:
    import winsdk.windows.ui
except ImportError:
    pass

class CaretType(enum.IntEnum):
    NORMAL = 0
    NULL = 1

class FindOptions(enum.IntFlag):
    NONE = 0
    WORD = 0x2
    CASE = 0x4

class FontStretch(enum.IntEnum):
    UNDEFINED = 0
    ULTRA_CONDENSED = 1
    EXTRA_CONDENSED = 2
    CONDENSED = 3
    SEMI_CONDENSED = 4
    NORMAL = 5
    SEMI_EXPANDED = 6
    EXPANDED = 7
    EXTRA_EXPANDED = 8
    ULTRA_EXPANDED = 9

class FontStyle(enum.IntEnum):
    NORMAL = 0
    OBLIQUE = 1
    ITALIC = 2

class FormatEffect(enum.IntEnum):
    OFF = 0
    ON = 1
    TOGGLE = 2
    UNDEFINED = 3

class HorizontalCharacterAlignment(enum.IntEnum):
    LEFT = 0
    RIGHT = 1
    CENTER = 2

class LetterCase(enum.IntEnum):
    LOWER = 0
    UPPER = 1

class LineSpacingRule(enum.IntEnum):
    UNDEFINED = 0
    SINGLE = 1
    ONE_AND_HALF = 2
    DOUBLE = 3
    AT_LEAST = 4
    EXACTLY = 5
    MULTIPLE = 6
    PERCENT = 7

class LinkType(enum.IntEnum):
    UNDEFINED = 0
    NOT_A_LINK = 1
    CLIENT_LINK = 2
    FRIENDLY_LINK_NAME = 3
    FRIENDLY_LINK_ADDRESS = 4
    AUTO_LINK = 5
    AUTO_LINK_EMAIL = 6
    AUTO_LINK_PHONE = 7
    AUTO_LINK_PATH = 8

class MarkerAlignment(enum.IntEnum):
    UNDEFINED = 0
    LEFT = 1
    CENTER = 2
    RIGHT = 3

class MarkerStyle(enum.IntEnum):
    UNDEFINED = 0
    PARENTHESIS = 1
    PARENTHESES = 2
    PERIOD = 3
    PLAIN = 4
    MINUS = 5
    NO_NUMBER = 6

class MarkerType(enum.IntEnum):
    UNDEFINED = 0
    NONE = 1
    BULLET = 2
    ARABIC = 3
    LOWERCASE_ENGLISH_LETTER = 4
    UPPERCASE_ENGLISH_LETTER = 5
    LOWERCASE_ROMAN = 6
    UPPERCASE_ROMAN = 7
    UNICODE_SEQUENCE = 8
    CIRCLED_NUMBER = 9
    BLACK_CIRCLE_WINGDING = 10
    WHITE_CIRCLE_WINGDING = 11
    ARABIC_WIDE = 12
    SIMPLIFIED_CHINESE = 13
    TRADITIONAL_CHINESE = 14
    JAPAN_SIMPLIFIED_CHINESE = 15
    JAPAN_KOREA = 16
    ARABIC_DICTIONARY = 17
    ARABIC_ABJAD = 18
    HEBREW = 19
    THAI_ALPHABETIC = 20
    THAI_NUMERIC = 21
    DEVANAGARI_VOWEL = 22
    DEVANAGARI_CONSONANT = 23
    DEVANAGARI_NUMERIC = 24

class ParagraphAlignment(enum.IntEnum):
    UNDEFINED = 0
    LEFT = 1
    CENTER = 2
    RIGHT = 3
    JUSTIFY = 4

class ParagraphStyle(enum.IntEnum):
    UNDEFINED = 0
    NONE = 1
    NORMAL = 2
    HEADING1 = 3
    HEADING2 = 4
    HEADING3 = 5
    HEADING4 = 6
    HEADING5 = 7
    HEADING6 = 8
    HEADING7 = 9
    HEADING8 = 10
    HEADING9 = 11

class PointOptions(enum.IntFlag):
    NONE = 0
    INCLUDE_INSET = 0x1
    START = 0x20
    CLIENT_COORDINATES = 0x100
    ALLOW_OFF_CLIENT = 0x200
    TRANSFORM = 0x400
    NO_HORIZONTAL_SCROLL = 0x10000
    NO_VERTICAL_SCROLL = 0x40000

class RangeGravity(enum.IntEnum):
    U_I_BEHAVIOR = 0
    BACKWARD = 1
    FORWARD = 2
    INWARD = 3
    OUTWARD = 4

class RichEditMathMode(enum.IntEnum):
    NO_MATH = 0
    MATH_ONLY = 1

class SelectionOptions(enum.IntFlag):
    START_ACTIVE = 0x1
    AT_END_OF_LINE = 0x2
    OVERTYPE = 0x4
    ACTIVE = 0x8
    REPLACE = 0x10

class SelectionType(enum.IntEnum):
    NONE = 0
    INSERTION_POINT = 1
    NORMAL = 2
    INLINE_SHAPE = 7
    SHAPE = 8

class TabAlignment(enum.IntEnum):
    LEFT = 0
    CENTER = 1
    RIGHT = 2
    DECIMAL = 3
    BAR = 4

class TabLeader(enum.IntEnum):
    SPACES = 0
    DOTS = 1
    DASHES = 2
    LINES = 3
    THICK_LINES = 4
    EQUALS = 5

class TextDecorations(enum.IntFlag):
    NONE = 0
    UNDERLINE = 0x1
    STRIKETHROUGH = 0x2

class TextGetOptions(enum.IntFlag):
    NONE = 0
    ADJUST_CRLF = 0x1
    USE_CRLF = 0x2
    USE_OBJECT_TEXT = 0x4
    ALLOW_FINAL_EOP = 0x8
    NO_HIDDEN = 0x20
    INCLUDE_NUMBERING = 0x40
    FORMAT_RTF = 0x2000
    USE_LF = 0x1000000

class TextRangeUnit(enum.IntEnum):
    CHARACTER = 0
    WORD = 1
    SENTENCE = 2
    PARAGRAPH = 3
    LINE = 4
    STORY = 5
    SCREEN = 6
    SECTION = 7
    WINDOW = 8
    CHARACTER_FORMAT = 9
    PARAGRAPH_FORMAT = 10
    OBJECT = 11
    HARD_PARAGRAPH = 12
    CLUSTER = 13
    BOLD = 14
    ITALIC = 15
    UNDERLINE = 16
    STRIKETHROUGH = 17
    PROTECTED_TEXT = 18
    LINK = 19
    SMALL_CAPS = 20
    ALL_CAPS = 21
    HIDDEN = 22
    OUTLINE = 23
    SHADOW = 24
    IMPRINT = 25
    DISABLED = 26
    REVISED = 27
    SUBSCRIPT = 28
    SUPERSCRIPT = 29
    FONT_BOUND = 30
    LINK_PROTECTED = 31
    CONTENT_LINK = 32

class TextScript(enum.IntEnum):
    UNDEFINED = 0
    ANSI = 1
    EAST_EUROPE = 2
    CYRILLIC = 3
    GREEK = 4
    TURKISH = 5
    HEBREW = 6
    ARABIC = 7
    BALTIC = 8
    VIETNAMESE = 9
    DEFAULT = 10
    SYMBOL = 11
    THAI = 12
    SHIFT_JIS = 13
    G_B2312 = 14
    HANGUL = 15
    BIG5 = 16
    P_C437 = 17
    OEM = 18
    MAC = 19
    ARMENIAN = 20
    SYRIAC = 21
    THAANA = 22
    DEVANAGARI = 23
    BENGALI = 24
    GURMUKHI = 25
    GUJARATI = 26
    ORIYA = 27
    TAMIL = 28
    TELUGU = 29
    KANNADA = 30
    MALAYALAM = 31
    SINHALA = 32
    LAO = 33
    TIBETAN = 34
    MYANMAR = 35
    GEORGIAN = 36
    JAMO = 37
    ETHIOPIC = 38
    CHEROKEE = 39
    ABORIGINAL = 40
    OGHAM = 41
    RUNIC = 42
    KHMER = 43
    MONGOLIAN = 44
    BRAILLE = 45
    YI = 46
    LIMBU = 47
    TAI_LE = 48
    NEW_TAI_LUE = 49
    SYLOTI_NAGRI = 50
    KHAROSHTHI = 51
    KAYAHLI = 52
    UNICODE_SYMBOL = 53
    EMOJI = 54
    GLAGOLITIC = 55
    LISU = 56
    VAI = 57
    N_KO = 58
    OSMANYA = 59
    PHAGS_PA = 60
    GOTHIC = 61
    DESERET = 62
    TIFINAGH = 63

class TextSetOptions(enum.IntFlag):
    NONE = 0
    UNICODE_BIDI = 0x1
    UNLINK = 0x8
    UNHIDE = 0x10
    CHECK_TEXT_LIMIT = 0x20
    FORMAT_RTF = 0x2000
    APPLY_RTF_DOCUMENT_DEFAULTS = 0x4000

class UnderlineType(enum.IntEnum):
    UNDEFINED = 0
    NONE = 1
    SINGLE = 2
    WORDS = 3
    DOUBLE = 4
    DOTTED = 5
    DASH = 6
    DASH_DOT = 7
    DASH_DOT_DOT = 8
    WAVE = 9
    THICK = 10
    THIN = 11
    DOUBLE_WAVE = 12
    HEAVY_WAVE = 13
    LONG_DASH = 14
    THICK_DASH = 15
    THICK_DASH_DOT = 16
    THICK_DASH_DOT_DOT = 17
    THICK_DOTTED = 18
    THICK_LONG_DASH = 19

class VerticalCharacterAlignment(enum.IntEnum):
    TOP = 0
    BASELINE = 1
    BOTTOM = 2

_ns_module._register_CaretType(CaretType)
_ns_module._register_FindOptions(FindOptions)
_ns_module._register_FontStretch(FontStretch)
_ns_module._register_FontStyle(FontStyle)
_ns_module._register_FormatEffect(FormatEffect)
_ns_module._register_HorizontalCharacterAlignment(HorizontalCharacterAlignment)
_ns_module._register_LetterCase(LetterCase)
_ns_module._register_LineSpacingRule(LineSpacingRule)
_ns_module._register_LinkType(LinkType)
_ns_module._register_MarkerAlignment(MarkerAlignment)
_ns_module._register_MarkerStyle(MarkerStyle)
_ns_module._register_MarkerType(MarkerType)
_ns_module._register_ParagraphAlignment(ParagraphAlignment)
_ns_module._register_ParagraphStyle(ParagraphStyle)
_ns_module._register_PointOptions(PointOptions)
_ns_module._register_RangeGravity(RangeGravity)
_ns_module._register_RichEditMathMode(RichEditMathMode)
_ns_module._register_SelectionOptions(SelectionOptions)
_ns_module._register_SelectionType(SelectionType)
_ns_module._register_TabAlignment(TabAlignment)
_ns_module._register_TabLeader(TabLeader)
_ns_module._register_TextDecorations(TextDecorations)
_ns_module._register_TextGetOptions(TextGetOptions)
_ns_module._register_TextRangeUnit(TextRangeUnit)
_ns_module._register_TextScript(TextScript)
_ns_module._register_TextSetOptions(TextSetOptions)
_ns_module._register_UnderlineType(UnderlineType)
_ns_module._register_VerticalCharacterAlignment(VerticalCharacterAlignment)

FontWeight = _ns_module.FontWeight
ContentLinkInfo = _ns_module.ContentLinkInfo
FontWeights = _ns_module.FontWeights
RichEditTextDocument = _ns_module.RichEditTextDocument
RichEditTextRange = _ns_module.RichEditTextRange
TextConstants = _ns_module.TextConstants
ITextCharacterFormat = _ns_module.ITextCharacterFormat
ITextDocument = _ns_module.ITextDocument
ITextParagraphFormat = _ns_module.ITextParagraphFormat
ITextRange = _ns_module.ITextRange
ITextSelection = _ns_module.ITextSelection



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Media.Core")

try:
    import winsdk.windows.applicationmodel.appservice
except ImportError:
    pass

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.graphics.directx.direct3d11
except ImportError:
    pass

try:
    import winsdk.windows.graphics.imaging
except ImportError:
    pass

try:
    import winsdk.windows.media.capture
except ImportError:
    pass

try:
    import winsdk.windows.media.capture.frames
except ImportError:
    pass

try:
    import winsdk.windows.media.devices
except ImportError:
    pass

try:
    import winsdk.windows.media.devices.core
except ImportError:
    pass

try:
    import winsdk.windows.media.faceanalysis
except ImportError:
    pass

try:
    import winsdk.windows.media.mediaproperties
except ImportError:
    pass

try:
    import winsdk.windows.media.playback
except ImportError:
    pass

try:
    import winsdk.windows.media.protection
except ImportError:
    pass

try:
    import winsdk.windows.media.streaming.adaptive
except ImportError:
    pass

try:
    import winsdk.windows.networking.backgroundtransfer
except ImportError:
    pass

try:
    import winsdk.windows.storage
except ImportError:
    pass

try:
    import winsdk.windows.storage.fileproperties
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

try:
    import winsdk.windows.ui
except ImportError:
    pass

class AudioDecoderDegradation(enum.IntEnum):
    NONE = 0
    DOWNMIX_TO2_CHANNELS = 1
    DOWNMIX_TO6_CHANNELS = 2
    DOWNMIX_TO8_CHANNELS = 3

class AudioDecoderDegradationReason(enum.IntEnum):
    NONE = 0
    LICENSING_REQUIREMENT = 1
    SPATIAL_AUDIO_NOT_SUPPORTED = 2

class CodecCategory(enum.IntEnum):
    ENCODER = 0
    DECODER = 1

class CodecKind(enum.IntEnum):
    AUDIO = 0
    VIDEO = 1

class FaceDetectionMode(enum.IntEnum):
    HIGH_PERFORMANCE = 0
    BALANCED = 1
    HIGH_QUALITY = 2

class MediaDecoderStatus(enum.IntEnum):
    FULLY_SUPPORTED = 0
    UNSUPPORTED_SUBTYPE = 1
    UNSUPPORTED_ENCODER_PROPERTIES = 2
    DEGRADED = 3

class MediaSourceState(enum.IntEnum):
    INITIAL = 0
    OPENING = 1
    OPENED = 2
    FAILED = 3
    CLOSED = 4

class MediaSourceStatus(enum.IntEnum):
    FULLY_SUPPORTED = 0
    UNKNOWN = 1

class MediaStreamSourceClosedReason(enum.IntEnum):
    DONE = 0
    UNKNOWN_ERROR = 1
    APP_REPORTED_ERROR = 2
    UNSUPPORTED_PROTECTION_SYSTEM = 3
    PROTECTION_SYSTEM_FAILURE = 4
    UNSUPPORTED_ENCODING_FORMAT = 5
    MISSING_SAMPLE_REQUESTED_EVENT_HANDLER = 6

class MediaStreamSourceErrorStatus(enum.IntEnum):
    OTHER = 0
    OUT_OF_MEMORY = 1
    FAILED_TO_OPEN_FILE = 2
    FAILED_TO_CONNECT_TO_SERVER = 3
    CONNECTION_TO_SERVER_LOST = 4
    UNSPECIFIED_NETWORK_ERROR = 5
    DECODE_ERROR = 6
    UNSUPPORTED_MEDIA_FORMAT = 7

class MediaTrackKind(enum.IntEnum):
    AUDIO = 0
    VIDEO = 1
    TIMED_METADATA = 2

class MseAppendMode(enum.IntEnum):
    SEGMENTS = 0
    SEQUENCE = 1

class MseEndOfStreamStatus(enum.IntEnum):
    SUCCESS = 0
    NETWORK_ERROR = 1
    DECODE_ERROR = 2
    UNKNOWN_ERROR = 3

class MseReadyState(enum.IntEnum):
    CLOSED = 0
    OPEN = 1
    ENDED = 2

class SceneAnalysisRecommendation(enum.IntEnum):
    STANDARD = 0
    HDR = 1
    LOW_LIGHT = 2

class TimedMetadataKind(enum.IntEnum):
    CAPTION = 0
    CHAPTER = 1
    CUSTOM = 2
    DATA = 3
    DESCRIPTION = 4
    SUBTITLE = 5
    IMAGE_SUBTITLE = 6
    SPEECH = 7

class TimedMetadataTrackErrorCode(enum.IntEnum):
    NONE = 0
    DATA_FORMAT_ERROR = 1
    NETWORK_ERROR = 2
    INTERNAL_ERROR = 3

class TimedTextBoutenPosition(enum.IntEnum):
    BEFORE = 0
    AFTER = 1
    OUTSIDE = 2

class TimedTextBoutenType(enum.IntEnum):
    NONE = 0
    AUTO = 1
    FILLED_CIRCLE = 2
    OPEN_CIRCLE = 3
    FILLED_DOT = 4
    OPEN_DOT = 5
    FILLED_SESAME = 6
    OPEN_SESAME = 7

class TimedTextDisplayAlignment(enum.IntEnum):
    BEFORE = 0
    AFTER = 1
    CENTER = 2

class TimedTextFlowDirection(enum.IntEnum):
    LEFT_TO_RIGHT = 0
    RIGHT_TO_LEFT = 1

class TimedTextFontStyle(enum.IntEnum):
    NORMAL = 0
    OBLIQUE = 1
    ITALIC = 2

class TimedTextLineAlignment(enum.IntEnum):
    START = 0
    END = 1
    CENTER = 2

class TimedTextRubyAlign(enum.IntEnum):
    CENTER = 0
    START = 1
    END = 2
    SPACE_AROUND = 3
    SPACE_BETWEEN = 4
    WITH_BASE = 5

class TimedTextRubyPosition(enum.IntEnum):
    BEFORE = 0
    AFTER = 1
    OUTSIDE = 2

class TimedTextRubyReserve(enum.IntEnum):
    NONE = 0
    BEFORE = 1
    AFTER = 2
    BOTH = 3
    OUTSIDE = 4

class TimedTextScrollMode(enum.IntEnum):
    POPON = 0
    ROLLUP = 1

class TimedTextUnit(enum.IntEnum):
    PIXELS = 0
    PERCENTAGE = 1

class TimedTextWeight(enum.IntEnum):
    NORMAL = 400
    BOLD = 700

class TimedTextWrapping(enum.IntEnum):
    NO_WRAP = 0
    WRAP = 1

class TimedTextWritingMode(enum.IntEnum):
    LEFT_RIGHT_TOP_BOTTOM = 0
    RIGHT_LEFT_TOP_BOTTOM = 1
    TOP_BOTTOM_RIGHT_LEFT = 2
    TOP_BOTTOM_LEFT_RIGHT = 3
    LEFT_RIGHT = 4
    RIGHT_LEFT = 5
    TOP_BOTTOM = 6

class VideoStabilizationEffectEnabledChangedReason(enum.IntEnum):
    PROGRAMMATIC = 0
    PIXEL_RATE_TOO_HIGH = 1
    RUNNING_SLOWLY = 2

_ns_module._register_AudioDecoderDegradation(AudioDecoderDegradation)
_ns_module._register_AudioDecoderDegradationReason(AudioDecoderDegradationReason)
_ns_module._register_CodecCategory(CodecCategory)
_ns_module._register_CodecKind(CodecKind)
_ns_module._register_FaceDetectionMode(FaceDetectionMode)
_ns_module._register_MediaDecoderStatus(MediaDecoderStatus)
_ns_module._register_MediaSourceState(MediaSourceState)
_ns_module._register_MediaSourceStatus(MediaSourceStatus)
_ns_module._register_MediaStreamSourceClosedReason(MediaStreamSourceClosedReason)
_ns_module._register_MediaStreamSourceErrorStatus(MediaStreamSourceErrorStatus)
_ns_module._register_MediaTrackKind(MediaTrackKind)
_ns_module._register_MseAppendMode(MseAppendMode)
_ns_module._register_MseEndOfStreamStatus(MseEndOfStreamStatus)
_ns_module._register_MseReadyState(MseReadyState)
_ns_module._register_SceneAnalysisRecommendation(SceneAnalysisRecommendation)
_ns_module._register_TimedMetadataKind(TimedMetadataKind)
_ns_module._register_TimedMetadataTrackErrorCode(TimedMetadataTrackErrorCode)
_ns_module._register_TimedTextBoutenPosition(TimedTextBoutenPosition)
_ns_module._register_TimedTextBoutenType(TimedTextBoutenType)
_ns_module._register_TimedTextDisplayAlignment(TimedTextDisplayAlignment)
_ns_module._register_TimedTextFlowDirection(TimedTextFlowDirection)
_ns_module._register_TimedTextFontStyle(TimedTextFontStyle)
_ns_module._register_TimedTextLineAlignment(TimedTextLineAlignment)
_ns_module._register_TimedTextRubyAlign(TimedTextRubyAlign)
_ns_module._register_TimedTextRubyPosition(TimedTextRubyPosition)
_ns_module._register_TimedTextRubyReserve(TimedTextRubyReserve)
_ns_module._register_TimedTextScrollMode(TimedTextScrollMode)
_ns_module._register_TimedTextUnit(TimedTextUnit)
_ns_module._register_TimedTextWeight(TimedTextWeight)
_ns_module._register_TimedTextWrapping(TimedTextWrapping)
_ns_module._register_TimedTextWritingMode(TimedTextWritingMode)
_ns_module._register_VideoStabilizationEffectEnabledChangedReason(VideoStabilizationEffectEnabledChangedReason)

MseTimeRange = _ns_module.MseTimeRange
TimedTextDouble = _ns_module.TimedTextDouble
TimedTextPadding = _ns_module.TimedTextPadding
TimedTextPoint = _ns_module.TimedTextPoint
TimedTextSize = _ns_module.TimedTextSize
AudioStreamDescriptor = _ns_module.AudioStreamDescriptor
AudioTrack = _ns_module.AudioTrack
AudioTrackOpenFailedEventArgs = _ns_module.AudioTrackOpenFailedEventArgs
AudioTrackSupportInfo = _ns_module.AudioTrackSupportInfo
ChapterCue = _ns_module.ChapterCue
CodecInfo = _ns_module.CodecInfo
CodecQuery = _ns_module.CodecQuery
CodecSubtypes = _ns_module.CodecSubtypes
DataCue = _ns_module.DataCue
FaceDetectedEventArgs = _ns_module.FaceDetectedEventArgs
FaceDetectionEffect = _ns_module.FaceDetectionEffect
FaceDetectionEffectDefinition = _ns_module.FaceDetectionEffectDefinition
FaceDetectionEffectFrame = _ns_module.FaceDetectionEffectFrame
HighDynamicRangeControl = _ns_module.HighDynamicRangeControl
HighDynamicRangeOutput = _ns_module.HighDynamicRangeOutput
ImageCue = _ns_module.ImageCue
InitializeMediaStreamSourceRequestedEventArgs = _ns_module.InitializeMediaStreamSourceRequestedEventArgs
LowLightFusion = _ns_module.LowLightFusion
LowLightFusionResult = _ns_module.LowLightFusionResult
MediaBinder = _ns_module.MediaBinder
MediaBindingEventArgs = _ns_module.MediaBindingEventArgs
MediaCueEventArgs = _ns_module.MediaCueEventArgs
MediaSource = _ns_module.MediaSource
MediaSourceAppServiceConnection = _ns_module.MediaSourceAppServiceConnection
MediaSourceError = _ns_module.MediaSourceError
MediaSourceOpenOperationCompletedEventArgs = _ns_module.MediaSourceOpenOperationCompletedEventArgs
MediaSourceStateChangedEventArgs = _ns_module.MediaSourceStateChangedEventArgs
MediaStreamSample = _ns_module.MediaStreamSample
MediaStreamSamplePropertySet = _ns_module.MediaStreamSamplePropertySet
MediaStreamSampleProtectionProperties = _ns_module.MediaStreamSampleProtectionProperties
MediaStreamSource = _ns_module.MediaStreamSource
MediaStreamSourceClosedEventArgs = _ns_module.MediaStreamSourceClosedEventArgs
MediaStreamSourceClosedRequest = _ns_module.MediaStreamSourceClosedRequest
MediaStreamSourceSampleRenderedEventArgs = _ns_module.MediaStreamSourceSampleRenderedEventArgs
MediaStreamSourceSampleRequest = _ns_module.MediaStreamSourceSampleRequest
MediaStreamSourceSampleRequestDeferral = _ns_module.MediaStreamSourceSampleRequestDeferral
MediaStreamSourceSampleRequestedEventArgs = _ns_module.MediaStreamSourceSampleRequestedEventArgs
MediaStreamSourceStartingEventArgs = _ns_module.MediaStreamSourceStartingEventArgs
MediaStreamSourceStartingRequest = _ns_module.MediaStreamSourceStartingRequest
MediaStreamSourceStartingRequestDeferral = _ns_module.MediaStreamSourceStartingRequestDeferral
MediaStreamSourceSwitchStreamsRequest = _ns_module.MediaStreamSourceSwitchStreamsRequest
MediaStreamSourceSwitchStreamsRequestDeferral = _ns_module.MediaStreamSourceSwitchStreamsRequestDeferral
MediaStreamSourceSwitchStreamsRequestedEventArgs = _ns_module.MediaStreamSourceSwitchStreamsRequestedEventArgs
MseSourceBuffer = _ns_module.MseSourceBuffer
MseSourceBufferList = _ns_module.MseSourceBufferList
MseStreamSource = _ns_module.MseStreamSource
SceneAnalysisEffect = _ns_module.SceneAnalysisEffect
SceneAnalysisEffectDefinition = _ns_module.SceneAnalysisEffectDefinition
SceneAnalysisEffectFrame = _ns_module.SceneAnalysisEffectFrame
SceneAnalyzedEventArgs = _ns_module.SceneAnalyzedEventArgs
SpeechCue = _ns_module.SpeechCue
TimedMetadataStreamDescriptor = _ns_module.TimedMetadataStreamDescriptor
TimedMetadataTrack = _ns_module.TimedMetadataTrack
TimedMetadataTrackError = _ns_module.TimedMetadataTrackError
TimedMetadataTrackFailedEventArgs = _ns_module.TimedMetadataTrackFailedEventArgs
TimedTextBouten = _ns_module.TimedTextBouten
TimedTextCue = _ns_module.TimedTextCue
TimedTextLine = _ns_module.TimedTextLine
TimedTextRegion = _ns_module.TimedTextRegion
TimedTextRuby = _ns_module.TimedTextRuby
TimedTextSource = _ns_module.TimedTextSource
TimedTextSourceResolveResultEventArgs = _ns_module.TimedTextSourceResolveResultEventArgs
TimedTextStyle = _ns_module.TimedTextStyle
TimedTextSubformat = _ns_module.TimedTextSubformat
VideoStabilizationEffect = _ns_module.VideoStabilizationEffect
VideoStabilizationEffectDefinition = _ns_module.VideoStabilizationEffectDefinition
VideoStabilizationEffectEnabledChangedEventArgs = _ns_module.VideoStabilizationEffectEnabledChangedEventArgs
VideoStreamDescriptor = _ns_module.VideoStreamDescriptor
VideoTrack = _ns_module.VideoTrack
VideoTrackOpenFailedEventArgs = _ns_module.VideoTrackOpenFailedEventArgs
VideoTrackSupportInfo = _ns_module.VideoTrackSupportInfo
IMediaCue = _ns_module.IMediaCue
IMediaSource = _ns_module.IMediaSource
IMediaStreamDescriptor = _ns_module.IMediaStreamDescriptor
IMediaStreamDescriptor2 = _ns_module.IMediaStreamDescriptor2
IMediaTrack = _ns_module.IMediaTrack
ISingleSelectMediaTrackList = _ns_module.ISingleSelectMediaTrackList
ITimedMetadataTrackProvider = _ns_module.ITimedMetadataTrackProvider



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Devices.I2c")

try:
    import winsdk.windows.devices.i2c.provider
except ImportError:
    pass

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

class I2cBusSpeed(enum.IntEnum):
    STANDARD_MODE = 0
    FAST_MODE = 1

class I2cSharingMode(enum.IntEnum):
    EXCLUSIVE = 0
    SHARED = 1

class I2cTransferStatus(enum.IntEnum):
    FULL_TRANSFER = 0
    PARTIAL_TRANSFER = 1
    SLAVE_ADDRESS_NOT_ACKNOWLEDGED = 2
    CLOCK_STRETCH_TIMEOUT = 3
    UNKNOWN_ERROR = 4

_ns_module._register_I2cBusSpeed(I2cBusSpeed)
_ns_module._register_I2cSharingMode(I2cSharingMode)
_ns_module._register_I2cTransferStatus(I2cTransferStatus)

I2cTransferResult = _ns_module.I2cTransferResult
I2cConnectionSettings = _ns_module.I2cConnectionSettings
I2cController = _ns_module.I2cController
I2cDevice = _ns_module.I2cDevice
II2cDeviceStatics = _ns_module.II2cDeviceStatics



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.ApplicationModel.DataTransfer")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.security.enterprisedata
except ImportError:
    pass

try:
    import winsdk.windows.storage
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

try:
    import winsdk.windows.ui
except ImportError:
    pass

class ClipboardHistoryItemsResultStatus(enum.IntEnum):
    SUCCESS = 0
    ACCESS_DENIED = 1
    CLIPBOARD_HISTORY_DISABLED = 2

class DataPackageOperation(enum.IntFlag):
    NONE = 0
    COPY = 0x1
    MOVE = 0x2
    LINK = 0x4

class SetHistoryItemAsContentStatus(enum.IntEnum):
    SUCCESS = 0
    ACCESS_DENIED = 1
    ITEM_DELETED = 2

class ShareUITheme(enum.IntEnum):
    DEFAULT = 0
    LIGHT = 1
    DARK = 2

_ns_module._register_ClipboardHistoryItemsResultStatus(ClipboardHistoryItemsResultStatus)
_ns_module._register_DataPackageOperation(DataPackageOperation)
_ns_module._register_SetHistoryItemAsContentStatus(SetHistoryItemAsContentStatus)
_ns_module._register_ShareUITheme(ShareUITheme)

Clipboard = _ns_module.Clipboard
ClipboardContentOptions = _ns_module.ClipboardContentOptions
ClipboardHistoryChangedEventArgs = _ns_module.ClipboardHistoryChangedEventArgs
ClipboardHistoryItem = _ns_module.ClipboardHistoryItem
ClipboardHistoryItemsResult = _ns_module.ClipboardHistoryItemsResult
DataPackage = _ns_module.DataPackage
DataPackagePropertySet = _ns_module.DataPackagePropertySet
DataPackagePropertySetView = _ns_module.DataPackagePropertySetView
DataPackageView = _ns_module.DataPackageView
DataProviderDeferral = _ns_module.DataProviderDeferral
DataProviderRequest = _ns_module.DataProviderRequest
DataRequest = _ns_module.DataRequest
DataRequestDeferral = _ns_module.DataRequestDeferral
DataRequestedEventArgs = _ns_module.DataRequestedEventArgs
DataTransferManager = _ns_module.DataTransferManager
HtmlFormatHelper = _ns_module.HtmlFormatHelper
OperationCompletedEventArgs = _ns_module.OperationCompletedEventArgs
ShareCompletedEventArgs = _ns_module.ShareCompletedEventArgs
ShareProvider = _ns_module.ShareProvider
ShareProviderOperation = _ns_module.ShareProviderOperation
ShareProvidersRequestedEventArgs = _ns_module.ShareProvidersRequestedEventArgs
ShareTargetInfo = _ns_module.ShareTargetInfo
ShareUIOptions = _ns_module.ShareUIOptions
SharedStorageAccessManager = _ns_module.SharedStorageAccessManager
StandardDataFormats = _ns_module.StandardDataFormats
TargetApplicationChosenEventArgs = _ns_module.TargetApplicationChosenEventArgs



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.UI.Input.Preview")

try:
    import winsdk.windows.ui.input
except ImportError:
    pass

try:
    import winsdk.windows.ui.windowmanagement
except ImportError:
    pass


InputActivationListenerPreview = _ns_module.InputActivationListenerPreview



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Phone.Management.Deployment")

try:
    import winsdk.windows.applicationmodel
except ImportError:
    pass

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.management.deployment
except ImportError:
    pass

class EnterpriseEnrollmentStatus(enum.IntEnum):
    SUCCESS = 0
    CANCELLED_BY_USER = 1
    UNKNOWN_FAILURE = 2

class EnterpriseStatus(enum.IntEnum):
    ENROLLED = 0
    DISABLED = 1
    REVOKED = 2
    EXPIRED = 3

_ns_module._register_EnterpriseEnrollmentStatus(EnterpriseEnrollmentStatus)
_ns_module._register_EnterpriseStatus(EnterpriseStatus)

Enterprise = _ns_module.Enterprise
EnterpriseEnrollmentManager = _ns_module.EnterpriseEnrollmentManager
EnterpriseEnrollmentResult = _ns_module.EnterpriseEnrollmentResult
InstallationManager = _ns_module.InstallationManager
PackageInstallResult = _ns_module.PackageInstallResult



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Web.AtomPub")

try:
    import winsdk.windows.data.xml.dom
except ImportError:
    pass

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.security.credentials
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

try:
    import winsdk.windows.web.syndication
except ImportError:
    pass


AtomPubClient = _ns_module.AtomPubClient
ResourceCollection = _ns_module.ResourceCollection
ServiceDocument = _ns_module.ServiceDocument
Workspace = _ns_module.Workspace



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.storage.streams

class CompressAlgorithm(enum.IntEnum):
    INVALID_ALGORITHM = 0
    NULL_ALGORITHM = 1
    MSZIP = 2
    XPRESS = 3
    XPRESS_HUFF = 4
    LZMS = 5

Self = typing.TypeVar('Self')

class Compressor(winsdk.system.Object):
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> Compressor: ...
    @typing.overload
    def __new__(cls: typing.Type[Compressor], underlying_stream: typing.Optional[winsdk.windows.storage.streams.IOutputStream]) -> Compressor:...
    @typing.overload
    def __new__(cls: typing.Type[Compressor], underlying_stream: typing.Optional[winsdk.windows.storage.streams.IOutputStream], algorithm: CompressAlgorithm, block_size: winsdk.system.UInt32) -> Compressor:...
    def close(self) -> None: ...
    def detach_stream(self) -> typing.Optional[winsdk.windows.storage.streams.IOutputStream]: ...
    def finish_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def flush_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def write_async(self, buffer: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> winsdk.windows.foundation.IAsyncOperationWithProgress[winsdk.system.UInt32, winsdk.system.UInt32]: ...

class Decompressor(winsdk.system.Object):
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> Decompressor: ...
    def __new__(cls: typing.Type[Decompressor], underlying_stream: typing.Optional[winsdk.windows.storage.streams.IInputStream]) -> Decompressor:...
    def close(self) -> None: ...
    def detach_stream(self) -> typing.Optional[winsdk.windows.storage.streams.IInputStream]: ...
    def read_async(self, buffer: typing.Optional[winsdk.windows.storage.streams.IBuffer], count: winsdk.system.UInt32, options: winsdk.windows.storage.streams.InputStreamOptions) -> winsdk.windows.foundation.IAsyncOperationWithProgress[winsdk.windows.storage.streams.IBuffer, winsdk.system.UInt32]: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Media.SpeechRecognition")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.globalization
except ImportError:
    pass

try:
    import winsdk.windows.storage
except ImportError:
    pass

class SpeechContinuousRecognitionMode(enum.IntEnum):
    DEFAULT = 0
    PAUSE_ON_RECOGNITION = 1

class SpeechRecognitionAudioProblem(enum.IntEnum):
    NONE = 0
    TOO_NOISY = 1
    NO_SIGNAL = 2
    TOO_LOUD = 3
    TOO_QUIET = 4
    TOO_FAST = 5
    TOO_SLOW = 6

class SpeechRecognitionConfidence(enum.IntEnum):
    HIGH = 0
    MEDIUM = 1
    LOW = 2
    REJECTED = 3

class SpeechRecognitionConstraintProbability(enum.IntEnum):
    DEFAULT = 0
    MIN = 1
    MAX = 2

class SpeechRecognitionConstraintType(enum.IntEnum):
    TOPIC = 0
    LIST = 1
    GRAMMAR = 2
    VOICE_COMMAND_DEFINITION = 3

class SpeechRecognitionResultStatus(enum.IntEnum):
    SUCCESS = 0
    TOPIC_LANGUAGE_NOT_SUPPORTED = 1
    GRAMMAR_LANGUAGE_MISMATCH = 2
    GRAMMAR_COMPILATION_FAILURE = 3
    AUDIO_QUALITY_FAILURE = 4
    USER_CANCELED = 5
    UNKNOWN = 6
    TIMEOUT_EXCEEDED = 7
    PAUSE_LIMIT_EXCEEDED = 8
    NETWORK_FAILURE = 9
    MICROPHONE_UNAVAILABLE = 10

class SpeechRecognitionScenario(enum.IntEnum):
    WEB_SEARCH = 0
    DICTATION = 1
    FORM_FILLING = 2

class SpeechRecognizerState(enum.IntEnum):
    IDLE = 0
    CAPTURING = 1
    PROCESSING = 2
    SOUND_STARTED = 3
    SOUND_ENDED = 4
    SPEECH_DETECTED = 5
    PAUSED = 6

_ns_module._register_SpeechContinuousRecognitionMode(SpeechContinuousRecognitionMode)
_ns_module._register_SpeechRecognitionAudioProblem(SpeechRecognitionAudioProblem)
_ns_module._register_SpeechRecognitionConfidence(SpeechRecognitionConfidence)
_ns_module._register_SpeechRecognitionConstraintProbability(SpeechRecognitionConstraintProbability)
_ns_module._register_SpeechRecognitionConstraintType(SpeechRecognitionConstraintType)
_ns_module._register_SpeechRecognitionResultStatus(SpeechRecognitionResultStatus)
_ns_module._register_SpeechRecognitionScenario(SpeechRecognitionScenario)
_ns_module._register_SpeechRecognizerState(SpeechRecognizerState)

SpeechContinuousRecognitionCompletedEventArgs = _ns_module.SpeechContinuousRecognitionCompletedEventArgs
SpeechContinuousRecognitionResultGeneratedEventArgs = _ns_module.SpeechContinuousRecognitionResultGeneratedEventArgs
SpeechContinuousRecognitionSession = _ns_module.SpeechContinuousRecognitionSession
SpeechRecognitionCompilationResult = _ns_module.SpeechRecognitionCompilationResult
SpeechRecognitionGrammarFileConstraint = _ns_module.SpeechRecognitionGrammarFileConstraint
SpeechRecognitionHypothesis = _ns_module.SpeechRecognitionHypothesis
SpeechRecognitionHypothesisGeneratedEventArgs = _ns_module.SpeechRecognitionHypothesisGeneratedEventArgs
SpeechRecognitionListConstraint = _ns_module.SpeechRecognitionListConstraint
SpeechRecognitionQualityDegradingEventArgs = _ns_module.SpeechRecognitionQualityDegradingEventArgs
SpeechRecognitionResult = _ns_module.SpeechRecognitionResult
SpeechRecognitionSemanticInterpretation = _ns_module.SpeechRecognitionSemanticInterpretation
SpeechRecognitionTopicConstraint = _ns_module.SpeechRecognitionTopicConstraint
SpeechRecognitionVoiceCommandDefinitionConstraint = _ns_module.SpeechRecognitionVoiceCommandDefinitionConstraint
SpeechRecognizer = _ns_module.SpeechRecognizer
SpeechRecognizerStateChangedEventArgs = _ns_module.SpeechRecognizerStateChangedEventArgs
SpeechRecognizerTimeouts = _ns_module.SpeechRecognizerTimeouts
SpeechRecognizerUIOptions = _ns_module.SpeechRecognizerUIOptions
VoiceCommandManager = _ns_module.VoiceCommandManager
VoiceCommandSet = _ns_module.VoiceCommandSet
ISpeechRecognitionConstraint = _ns_module.ISpeechRecognitionConstraint



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.ApplicationModel.ConversationalAgent")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.media.audio
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

class ActivationSignalDetectionConfigurationCreationStatus(enum.IntEnum):
    SUCCESS = 0
    SIGNAL_ID_NOT_AVAILABLE = 1
    MODEL_ID_NOT_SUPPORTED = 2
    INVALID_SIGNAL_ID = 3
    INVALID_MODEL_ID = 4
    INVALID_DISPLAY_NAME = 5
    CONFIGURATION_ALREADY_EXISTS = 6
    CREATION_NOT_SUPPORTED = 7

class ActivationSignalDetectionConfigurationRemovalResult(enum.IntEnum):
    SUCCESS = 0
    NOT_FOUND = 1
    CURRENTLY_ENABLED = 2
    REMOVAL_NOT_SUPPORTED = 3

class ActivationSignalDetectionConfigurationSetModelDataResult(enum.IntEnum):
    SUCCESS = 0
    EMPTY_MODEL_DATA = 1
    UNSUPPORTED_FORMAT = 2
    CONFIGURATION_CURRENTLY_ENABLED = 3
    INVALID_DATA = 4
    SET_MODEL_DATA_NOT_SUPPORTED = 5
    CONFIGURATION_NOT_FOUND = 6
    UNKNOWN_ERROR = 7

class ActivationSignalDetectionConfigurationStateChangeResult(enum.IntEnum):
    SUCCESS = 0
    NO_MODEL_DATA = 1
    CONFIGURATION_NOT_FOUND = 2

class ActivationSignalDetectionTrainingDataFormat(enum.IntEnum):
    VOICE8K_HZ8_BIT_MONO = 0
    VOICE8K_HZ16_BIT_MONO = 1
    VOICE16K_HZ8_BIT_MONO = 2
    VOICE16K_HZ16_BIT_MONO = 3
    VOICE_O_E_M_DEFINED = 4
    AUDIO44K_HZ8_BIT_MONO = 5
    AUDIO44K_HZ16_BIT_MONO = 6
    AUDIO48K_HZ8_BIT_MONO = 7
    AUDIO48K_HZ16_BIT_MONO = 8
    AUDIO_O_E_M_DEFINED = 9
    OTHER_O_E_M_DEFINED = 10

class ActivationSignalDetectorKind(enum.IntEnum):
    AUDIO_PATTERN = 0
    AUDIO_IMPULSE = 1
    HARDWARE_EVENT = 2

class ActivationSignalDetectorPowerState(enum.IntEnum):
    HIGH_POWER = 0
    CONNECTED_LOW_POWER = 1
    DISCONNECTED_LOW_POWER = 2

class ConversationalAgentActivationKind(enum.IntEnum):
    VOICE_ACTIVATION_PREVIEW = 0
    FOREGROUND = 1

class ConversationalAgentActivationResult(enum.IntEnum):
    SUCCESS = 0
    AGENT_INACTIVE = 1
    SCREEN_NOT_AVAILABLE = 2
    AGENT_INTERRUPTED = 3

class ConversationalAgentSessionUpdateResponse(enum.IntEnum):
    SUCCESS = 0
    FAILED = 1

class ConversationalAgentState(enum.IntEnum):
    INACTIVE = 0
    DETECTING = 1
    LISTENING = 2
    WORKING = 3
    SPEAKING = 4
    LISTENING_AND_SPEAKING = 5

class ConversationalAgentSystemStateChangeType(enum.IntEnum):
    USER_AUTHENTICATION = 0
    SCREEN_AVAILABILITY = 1
    INDICATOR_LIGHT_AVAILABILITY = 2
    VOICE_ACTIVATION_AVAILABILITY = 3

class ConversationalAgentVoiceActivationPrerequisiteKind(enum.IntEnum):
    MICROPHONE_PERMISSION = 0
    KNOWN_AGENTS = 1
    AGENT_ALLOWED = 2
    APP_CAPABILITY = 3
    BACKGROUND_TASK_REGISTRATION = 4
    POLICY_PERMISSION = 5

class DetectionConfigurationAvailabilityChangeKind(enum.IntEnum):
    SYSTEM_RESOURCE_ACCESS = 0
    PERMISSION = 1
    LOCK_SCREEN_PERMISSION = 2

class DetectionConfigurationTrainingStatus(enum.IntEnum):
    SUCCESS = 0
    FORMAT_NOT_SUPPORTED = 1
    VOICE_TOO_QUIET = 2
    VOICE_TOO_LOUD = 3
    VOICE_TOO_FAST = 4
    VOICE_TOO_SLOW = 5
    VOICE_QUALITY_PROBLEM = 6
    TRAINING_SYSTEM_INTERNAL_ERROR = 7
    TRAINING_TIMED_OUT = 8
    CONFIGURATION_NOT_FOUND = 9

class SignalDetectorResourceKind(enum.IntEnum):
    PARALLEL_MODEL_SUPPORT = 0
    PARALLEL_MODEL_SUPPORT_FOR_AGENT = 1
    PARALLEL_SIGNAL_SUPPORT = 2
    PARALLEL_SIGNAL_SUPPORT_FOR_AGENT = 3
    DISPLAY_OFF_SUPPORT = 4
    PLUGGED_IN_POWER = 5
    DETECTOR = 6
    SUPPORTED_SLEEP_STATE = 7
    SUPPORTED_BATTERY_SAVER_STATE = 8
    SCREEN_AVAILABILITY = 9
    INPUT_HARDWARE = 10
    ACOUSTIC_ECHO_CANCELLATION = 11
    MODEL_ID_SUPPORT = 12
    DATA_CHANNEL = 13

_ns_module._register_ActivationSignalDetectionConfigurationCreationStatus(ActivationSignalDetectionConfigurationCreationStatus)
_ns_module._register_ActivationSignalDetectionConfigurationRemovalResult(ActivationSignalDetectionConfigurationRemovalResult)
_ns_module._register_ActivationSignalDetectionConfigurationSetModelDataResult(ActivationSignalDetectionConfigurationSetModelDataResult)
_ns_module._register_ActivationSignalDetectionConfigurationStateChangeResult(ActivationSignalDetectionConfigurationStateChangeResult)
_ns_module._register_ActivationSignalDetectionTrainingDataFormat(ActivationSignalDetectionTrainingDataFormat)
_ns_module._register_ActivationSignalDetectorKind(ActivationSignalDetectorKind)
_ns_module._register_ActivationSignalDetectorPowerState(ActivationSignalDetectorPowerState)
_ns_module._register_ConversationalAgentActivationKind(ConversationalAgentActivationKind)
_ns_module._register_ConversationalAgentActivationResult(ConversationalAgentActivationResult)
_ns_module._register_ConversationalAgentSessionUpdateResponse(ConversationalAgentSessionUpdateResponse)
_ns_module._register_ConversationalAgentState(ConversationalAgentState)
_ns_module._register_ConversationalAgentSystemStateChangeType(ConversationalAgentSystemStateChangeType)
_ns_module._register_ConversationalAgentVoiceActivationPrerequisiteKind(ConversationalAgentVoiceActivationPrerequisiteKind)
_ns_module._register_DetectionConfigurationAvailabilityChangeKind(DetectionConfigurationAvailabilityChangeKind)
_ns_module._register_DetectionConfigurationTrainingStatus(DetectionConfigurationTrainingStatus)
_ns_module._register_SignalDetectorResourceKind(SignalDetectorResourceKind)

ActivationSignalDetectionConfiguration = _ns_module.ActivationSignalDetectionConfiguration
ActivationSignalDetectionConfigurationCreationResult = _ns_module.ActivationSignalDetectionConfigurationCreationResult
ActivationSignalDetector = _ns_module.ActivationSignalDetector
ConversationalAgentDetectorManager = _ns_module.ConversationalAgentDetectorManager
ConversationalAgentSession = _ns_module.ConversationalAgentSession
ConversationalAgentSessionInterruptedEventArgs = _ns_module.ConversationalAgentSessionInterruptedEventArgs
ConversationalAgentSignal = _ns_module.ConversationalAgentSignal
ConversationalAgentSignalDetectedEventArgs = _ns_module.ConversationalAgentSignalDetectedEventArgs
ConversationalAgentSystemStateChangedEventArgs = _ns_module.ConversationalAgentSystemStateChangedEventArgs
DetectionConfigurationAvailabilityChangedEventArgs = _ns_module.DetectionConfigurationAvailabilityChangedEventArgs
DetectionConfigurationAvailabilityInfo = _ns_module.DetectionConfigurationAvailabilityInfo



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.applicationmodel.search
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.storage.streams

class SearchSuggestionKind(enum.IntEnum):
    QUERY = 0
    RESULT = 1
    SEPARATOR = 2

Self = typing.TypeVar('Self')

class RequestingFocusOnKeyboardInputEventArgs(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> RequestingFocusOnKeyboardInputEventArgs: ...

class SearchSuggestion(winsdk.system.Object):
    detail_text: str
    image: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStreamReference]
    image_alternate_text: str
    kind: SearchSuggestionKind
    tag: str
    text: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SearchSuggestion: ...

class SearchSuggestionManager(winsdk.system.Object):
    search_history_enabled: winsdk.system.Boolean
    search_history_context: str
    suggestions: typing.Optional[winsdk.windows.foundation.collections.IObservableVector[SearchSuggestion]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SearchSuggestionManager: ...
    def __new__(cls: typing.Type[SearchSuggestionManager]) -> SearchSuggestionManager:...
    @typing.overload
    def add_to_history(self, query_text: str) -> None: ...
    @typing.overload
    def add_to_history(self, query_text: str, language: str) -> None: ...
    def clear_history(self) -> None: ...
    def set_local_content_suggestion_settings(self, settings: typing.Optional[winsdk.windows.applicationmodel.search.LocalContentSuggestionSettings]) -> None: ...
    @typing.overload
    def set_query(self, query_text: str) -> None: ...
    @typing.overload
    def set_query(self, query_text: str, language: str) -> None: ...
    @typing.overload
    def set_query(self, query_text: str, language: str, linguistic_details: typing.Optional[winsdk.windows.applicationmodel.search.SearchQueryLinguisticDetails]) -> None: ...
    def add_requesting_focus_on_keyboard_input(self, handler: winsdk.windows.foundation.TypedEventHandler[SearchSuggestionManager, RequestingFocusOnKeyboardInputEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_requesting_focus_on_keyboard_input(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_suggestions_requested(self, handler: winsdk.windows.foundation.TypedEventHandler[SearchSuggestionManager, SearchSuggestionsRequestedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_suggestions_requested(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class SearchSuggestionsRequestedEventArgs(winsdk.system.Object):
    language: str
    linguistic_details: typing.Optional[winsdk.windows.applicationmodel.search.SearchQueryLinguisticDetails]
    query_text: str
    request: typing.Optional[winsdk.windows.applicationmodel.search.SearchSuggestionsRequest]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SearchSuggestionsRequestedEventArgs: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import datetime
import sys
import types
import typing

import winsdk.system

Self = typing.TypeVar('Self')

class DisplayAdapterId:
    low_part: winsdk.system.UInt32
    high_part: winsdk.system.Int32
    def __new__(cls: typing.Type[DisplayAdapterId], low_part: winsdk.system.UInt32, high_part: winsdk.system.Int32) -> DisplayAdapterId: ...

class DisplayId:
    value: winsdk.system.UInt64
    def __new__(cls: typing.Type[DisplayId], value: winsdk.system.UInt64) -> DisplayId: ...

class PointInt32:
    x: winsdk.system.Int32
    y: winsdk.system.Int32
    def __new__(cls: typing.Type[PointInt32], x: winsdk.system.Int32, y: winsdk.system.Int32) -> PointInt32: ...

class RectInt32:
    x: winsdk.system.Int32
    y: winsdk.system.Int32
    width: winsdk.system.Int32
    height: winsdk.system.Int32
    def __new__(cls: typing.Type[RectInt32], x: winsdk.system.Int32, y: winsdk.system.Int32, width: winsdk.system.Int32, height: winsdk.system.Int32) -> RectInt32: ...

class SizeInt32:
    width: winsdk.system.Int32
    height: winsdk.system.Int32
    def __new__(cls: typing.Type[SizeInt32], width: winsdk.system.Int32, height: winsdk.system.Int32) -> SizeInt32: ...

class IGeometrySource2D(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IGeometrySource2D: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.graphics.imaging
import winsdk.windows.storage.streams

class SocialFeedItemStyle(enum.IntEnum):
    DEFAULT = 0
    PHOTO = 1

class SocialFeedKind(enum.IntEnum):
    HOME_FEED = 0
    CONTACT_FEED = 1
    DASHBOARD = 2

class SocialFeedUpdateMode(enum.IntEnum):
    APPEND = 0
    REPLACE = 1

class SocialItemBadgeStyle(enum.IntEnum):
    HIDDEN = 0
    VISIBLE = 1
    VISIBLE_WITH_COUNT = 2

Self = typing.TypeVar('Self')

class SocialFeedChildItem(winsdk.system.Object):
    timestamp: datetime.datetime
    target_uri: typing.Optional[winsdk.windows.foundation.Uri]
    shared_item: typing.Optional[SocialFeedSharedItem]
    author: typing.Optional[SocialUserInfo]
    primary_content: typing.Optional[SocialFeedContent]
    secondary_content: typing.Optional[SocialFeedContent]
    thumbnails: typing.Optional[winsdk.windows.foundation.collections.IVector[SocialItemThumbnail]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SocialFeedChildItem: ...
    def __new__(cls: typing.Type[SocialFeedChildItem]) -> SocialFeedChildItem:...

class SocialFeedContent(winsdk.system.Object):
    title: str
    target_uri: typing.Optional[winsdk.windows.foundation.Uri]
    message: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SocialFeedContent: ...

class SocialFeedItem(winsdk.system.Object):
    timestamp: datetime.datetime
    target_uri: typing.Optional[winsdk.windows.foundation.Uri]
    style: SocialFeedItemStyle
    shared_item: typing.Optional[SocialFeedSharedItem]
    remote_id: str
    child_item: typing.Optional[SocialFeedChildItem]
    badge_style: SocialItemBadgeStyle
    badge_count_value: winsdk.system.Int32
    author: typing.Optional[SocialUserInfo]
    thumbnails: typing.Optional[winsdk.windows.foundation.collections.IVector[SocialItemThumbnail]]
    primary_content: typing.Optional[SocialFeedContent]
    secondary_content: typing.Optional[SocialFeedContent]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SocialFeedItem: ...
    def __new__(cls: typing.Type[SocialFeedItem]) -> SocialFeedItem:...

class SocialFeedSharedItem(winsdk.system.Object):
    timestamp: datetime.datetime
    thumbnail: typing.Optional[SocialItemThumbnail]
    target_uri: typing.Optional[winsdk.windows.foundation.Uri]
    original_source: typing.Optional[winsdk.windows.foundation.Uri]
    content: typing.Optional[SocialFeedContent]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SocialFeedSharedItem: ...
    def __new__(cls: typing.Type[SocialFeedSharedItem]) -> SocialFeedSharedItem:...

class SocialItemThumbnail(winsdk.system.Object):
    target_uri: typing.Optional[winsdk.windows.foundation.Uri]
    image_uri: typing.Optional[winsdk.windows.foundation.Uri]
    bitmap_size: winsdk.windows.graphics.imaging.BitmapSize
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SocialItemThumbnail: ...
    def __new__(cls: typing.Type[SocialItemThumbnail]) -> SocialItemThumbnail:...
    def set_image_async(self, image: typing.Optional[winsdk.windows.storage.streams.IInputStream]) -> winsdk.windows.foundation.IAsyncAction: ...

class SocialUserInfo(winsdk.system.Object):
    user_name: str
    target_uri: typing.Optional[winsdk.windows.foundation.Uri]
    remote_id: str
    display_name: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SocialUserInfo: ...

